# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['ZoneArgs', 'Zone']

@pulumi.input_type
class ZoneArgs:
    def __init__(__self__, *,
                 region_id: pulumi.Input[str],
                 compute_ids: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 custom_properties: Optional[pulumi.Input[Mapping[str, Any]]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 folder: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 placement_policy: Optional[pulumi.Input[str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input['ZoneTagArgs']]]] = None,
                 tags_to_matches: Optional[pulumi.Input[Sequence[pulumi.Input['ZoneTagsToMatchArgs']]]] = None):
        """
        The set of arguments for constructing a Zone resource.
        :param pulumi.Input[str] region_id: The id of the region for which this zone is created.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] compute_ids: The ids of the compute resources that will be explicitly assigned to this zone.
        :param pulumi.Input[Mapping[str, Any]] custom_properties: A list of key value pair of properties that will be used.
        :param pulumi.Input[str] description: A human-friendly description.
        :param pulumi.Input[str] folder: The folder relative path to the datacenter where resources are deployed to (only applicable for vSphere cloud zones).
        :param pulumi.Input[str] name: A human-friendly name used as an identifier for the zone resource instance.
        :param pulumi.Input[str] placement_policy: The placement policy for the zone. One of `DEFAULT`, `SPREAD` or `BINPACK`. Default is `DEFAULT`.
        :param pulumi.Input[Sequence[pulumi.Input['ZoneTagArgs']]] tags: A set of tag keys and optional values that were set on this resource:
        :param pulumi.Input[Sequence[pulumi.Input['ZoneTagsToMatchArgs']]] tags_to_matches: A set of tag keys and optional values for compute resource filtering:
        """
        pulumi.set(__self__, "region_id", region_id)
        if compute_ids is not None:
            pulumi.set(__self__, "compute_ids", compute_ids)
        if custom_properties is not None:
            pulumi.set(__self__, "custom_properties", custom_properties)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if folder is not None:
            pulumi.set(__self__, "folder", folder)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if placement_policy is not None:
            pulumi.set(__self__, "placement_policy", placement_policy)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)
        if tags_to_matches is not None:
            pulumi.set(__self__, "tags_to_matches", tags_to_matches)

    @property
    @pulumi.getter(name="regionId")
    def region_id(self) -> pulumi.Input[str]:
        """
        The id of the region for which this zone is created.
        """
        return pulumi.get(self, "region_id")

    @region_id.setter
    def region_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "region_id", value)

    @property
    @pulumi.getter(name="computeIds")
    def compute_ids(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        The ids of the compute resources that will be explicitly assigned to this zone.
        """
        return pulumi.get(self, "compute_ids")

    @compute_ids.setter
    def compute_ids(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "compute_ids", value)

    @property
    @pulumi.getter(name="customProperties")
    def custom_properties(self) -> Optional[pulumi.Input[Mapping[str, Any]]]:
        """
        A list of key value pair of properties that will be used.
        """
        return pulumi.get(self, "custom_properties")

    @custom_properties.setter
    def custom_properties(self, value: Optional[pulumi.Input[Mapping[str, Any]]]):
        pulumi.set(self, "custom_properties", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[str]]:
        """
        A human-friendly description.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter
    def folder(self) -> Optional[pulumi.Input[str]]:
        """
        The folder relative path to the datacenter where resources are deployed to (only applicable for vSphere cloud zones).
        """
        return pulumi.get(self, "folder")

    @folder.setter
    def folder(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "folder", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        A human-friendly name used as an identifier for the zone resource instance.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="placementPolicy")
    def placement_policy(self) -> Optional[pulumi.Input[str]]:
        """
        The placement policy for the zone. One of `DEFAULT`, `SPREAD` or `BINPACK`. Default is `DEFAULT`.
        """
        return pulumi.get(self, "placement_policy")

    @placement_policy.setter
    def placement_policy(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "placement_policy", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['ZoneTagArgs']]]]:
        """
        A set of tag keys and optional values that were set on this resource:
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['ZoneTagArgs']]]]):
        pulumi.set(self, "tags", value)

    @property
    @pulumi.getter(name="tagsToMatches")
    def tags_to_matches(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['ZoneTagsToMatchArgs']]]]:
        """
        A set of tag keys and optional values for compute resource filtering:
        """
        return pulumi.get(self, "tags_to_matches")

    @tags_to_matches.setter
    def tags_to_matches(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['ZoneTagsToMatchArgs']]]]):
        pulumi.set(self, "tags_to_matches", value)


@pulumi.input_type
class _ZoneState:
    def __init__(__self__, *,
                 cloud_account_id: Optional[pulumi.Input[str]] = None,
                 compute_ids: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 created_at: Optional[pulumi.Input[str]] = None,
                 custom_properties: Optional[pulumi.Input[Mapping[str, Any]]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 external_region_id: Optional[pulumi.Input[str]] = None,
                 folder: Optional[pulumi.Input[str]] = None,
                 links: Optional[pulumi.Input[Sequence[pulumi.Input['ZoneLinkArgs']]]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 org_id: Optional[pulumi.Input[str]] = None,
                 owner: Optional[pulumi.Input[str]] = None,
                 placement_policy: Optional[pulumi.Input[str]] = None,
                 region_id: Optional[pulumi.Input[str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input['ZoneTagArgs']]]] = None,
                 tags_to_matches: Optional[pulumi.Input[Sequence[pulumi.Input['ZoneTagsToMatchArgs']]]] = None,
                 updated_at: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering Zone resources.
        :param pulumi.Input[str] cloud_account_id: The ID of the cloud account this zone belongs to.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] compute_ids: The ids of the compute resources that will be explicitly assigned to this zone.
        :param pulumi.Input[str] created_at: Date when the entity was created. The date is in ISO 8601 and UTC.
        :param pulumi.Input[Mapping[str, Any]] custom_properties: A list of key value pair of properties that will be used.
        :param pulumi.Input[str] description: A human-friendly description.
        :param pulumi.Input[str] external_region_id: The id of the region for which this zone is defined.
        :param pulumi.Input[str] folder: The folder relative path to the datacenter where resources are deployed to (only applicable for vSphere cloud zones).
        :param pulumi.Input[Sequence[pulumi.Input['ZoneLinkArgs']]] links: HATEOAS of entity.
        :param pulumi.Input[str] name: A human-friendly name used as an identifier for the zone resource instance.
        :param pulumi.Input[str] org_id: The id of the organization this entity belongs to.
        :param pulumi.Input[str] owner: Email of the user that owns the entity.
        :param pulumi.Input[str] placement_policy: The placement policy for the zone. One of `DEFAULT`, `SPREAD` or `BINPACK`. Default is `DEFAULT`.
        :param pulumi.Input[str] region_id: The id of the region for which this zone is created.
        :param pulumi.Input[Sequence[pulumi.Input['ZoneTagArgs']]] tags: A set of tag keys and optional values that were set on this resource:
        :param pulumi.Input[Sequence[pulumi.Input['ZoneTagsToMatchArgs']]] tags_to_matches: A set of tag keys and optional values for compute resource filtering:
        :param pulumi.Input[str] updated_at: Date when the entity was last updated. The date is ISO 8601 and UTC.
        """
        if cloud_account_id is not None:
            pulumi.set(__self__, "cloud_account_id", cloud_account_id)
        if compute_ids is not None:
            pulumi.set(__self__, "compute_ids", compute_ids)
        if created_at is not None:
            pulumi.set(__self__, "created_at", created_at)
        if custom_properties is not None:
            pulumi.set(__self__, "custom_properties", custom_properties)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if external_region_id is not None:
            pulumi.set(__self__, "external_region_id", external_region_id)
        if folder is not None:
            pulumi.set(__self__, "folder", folder)
        if links is not None:
            pulumi.set(__self__, "links", links)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if org_id is not None:
            pulumi.set(__self__, "org_id", org_id)
        if owner is not None:
            pulumi.set(__self__, "owner", owner)
        if placement_policy is not None:
            pulumi.set(__self__, "placement_policy", placement_policy)
        if region_id is not None:
            pulumi.set(__self__, "region_id", region_id)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)
        if tags_to_matches is not None:
            pulumi.set(__self__, "tags_to_matches", tags_to_matches)
        if updated_at is not None:
            pulumi.set(__self__, "updated_at", updated_at)

    @property
    @pulumi.getter(name="cloudAccountId")
    def cloud_account_id(self) -> Optional[pulumi.Input[str]]:
        """
        The ID of the cloud account this zone belongs to.
        """
        return pulumi.get(self, "cloud_account_id")

    @cloud_account_id.setter
    def cloud_account_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "cloud_account_id", value)

    @property
    @pulumi.getter(name="computeIds")
    def compute_ids(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        The ids of the compute resources that will be explicitly assigned to this zone.
        """
        return pulumi.get(self, "compute_ids")

    @compute_ids.setter
    def compute_ids(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "compute_ids", value)

    @property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> Optional[pulumi.Input[str]]:
        """
        Date when the entity was created. The date is in ISO 8601 and UTC.
        """
        return pulumi.get(self, "created_at")

    @created_at.setter
    def created_at(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "created_at", value)

    @property
    @pulumi.getter(name="customProperties")
    def custom_properties(self) -> Optional[pulumi.Input[Mapping[str, Any]]]:
        """
        A list of key value pair of properties that will be used.
        """
        return pulumi.get(self, "custom_properties")

    @custom_properties.setter
    def custom_properties(self, value: Optional[pulumi.Input[Mapping[str, Any]]]):
        pulumi.set(self, "custom_properties", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[str]]:
        """
        A human-friendly description.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="externalRegionId")
    def external_region_id(self) -> Optional[pulumi.Input[str]]:
        """
        The id of the region for which this zone is defined.
        """
        return pulumi.get(self, "external_region_id")

    @external_region_id.setter
    def external_region_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "external_region_id", value)

    @property
    @pulumi.getter
    def folder(self) -> Optional[pulumi.Input[str]]:
        """
        The folder relative path to the datacenter where resources are deployed to (only applicable for vSphere cloud zones).
        """
        return pulumi.get(self, "folder")

    @folder.setter
    def folder(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "folder", value)

    @property
    @pulumi.getter
    def links(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['ZoneLinkArgs']]]]:
        """
        HATEOAS of entity.
        """
        return pulumi.get(self, "links")

    @links.setter
    def links(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['ZoneLinkArgs']]]]):
        pulumi.set(self, "links", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        A human-friendly name used as an identifier for the zone resource instance.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="orgId")
    def org_id(self) -> Optional[pulumi.Input[str]]:
        """
        The id of the organization this entity belongs to.
        """
        return pulumi.get(self, "org_id")

    @org_id.setter
    def org_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "org_id", value)

    @property
    @pulumi.getter
    def owner(self) -> Optional[pulumi.Input[str]]:
        """
        Email of the user that owns the entity.
        """
        return pulumi.get(self, "owner")

    @owner.setter
    def owner(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "owner", value)

    @property
    @pulumi.getter(name="placementPolicy")
    def placement_policy(self) -> Optional[pulumi.Input[str]]:
        """
        The placement policy for the zone. One of `DEFAULT`, `SPREAD` or `BINPACK`. Default is `DEFAULT`.
        """
        return pulumi.get(self, "placement_policy")

    @placement_policy.setter
    def placement_policy(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "placement_policy", value)

    @property
    @pulumi.getter(name="regionId")
    def region_id(self) -> Optional[pulumi.Input[str]]:
        """
        The id of the region for which this zone is created.
        """
        return pulumi.get(self, "region_id")

    @region_id.setter
    def region_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "region_id", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['ZoneTagArgs']]]]:
        """
        A set of tag keys and optional values that were set on this resource:
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['ZoneTagArgs']]]]):
        pulumi.set(self, "tags", value)

    @property
    @pulumi.getter(name="tagsToMatches")
    def tags_to_matches(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['ZoneTagsToMatchArgs']]]]:
        """
        A set of tag keys and optional values for compute resource filtering:
        """
        return pulumi.get(self, "tags_to_matches")

    @tags_to_matches.setter
    def tags_to_matches(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['ZoneTagsToMatchArgs']]]]):
        pulumi.set(self, "tags_to_matches", value)

    @property
    @pulumi.getter(name="updatedAt")
    def updated_at(self) -> Optional[pulumi.Input[str]]:
        """
        Date when the entity was last updated. The date is ISO 8601 and UTC.
        """
        return pulumi.get(self, "updated_at")

    @updated_at.setter
    def updated_at(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "updated_at", value)


class Zone(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 compute_ids: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 custom_properties: Optional[pulumi.Input[Mapping[str, Any]]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 folder: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 placement_policy: Optional[pulumi.Input[str]] = None,
                 region_id: Optional[pulumi.Input[str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['ZoneTagArgs']]]]] = None,
                 tags_to_matches: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['ZoneTagsToMatchArgs']]]]] = None,
                 __props__=None):
        """
        ## Example Usage
        ### S

        This is an example of how to create a zone resource.

        ```python
        import pulumi
        import pulumiverse_vra as vra

        this = vra.zone.Zone("this",
            description="my terraform test cloud zone",
            region_id=data["vra_region"]["this"]["id"],
            tags=[
                vra.zone.ZoneTagArgs(
                    key="my-tf-key",
                    value="my-tf-value",
                ),
                vra.zone.ZoneTagArgs(
                    key="tf-foo",
                    value="tf-bar",
                ),
            ])
        ```

        A zone resource supports the following arguments:

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] compute_ids: The ids of the compute resources that will be explicitly assigned to this zone.
        :param pulumi.Input[Mapping[str, Any]] custom_properties: A list of key value pair of properties that will be used.
        :param pulumi.Input[str] description: A human-friendly description.
        :param pulumi.Input[str] folder: The folder relative path to the datacenter where resources are deployed to (only applicable for vSphere cloud zones).
        :param pulumi.Input[str] name: A human-friendly name used as an identifier for the zone resource instance.
        :param pulumi.Input[str] placement_policy: The placement policy for the zone. One of `DEFAULT`, `SPREAD` or `BINPACK`. Default is `DEFAULT`.
        :param pulumi.Input[str] region_id: The id of the region for which this zone is created.
        :param pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['ZoneTagArgs']]]] tags: A set of tag keys and optional values that were set on this resource:
        :param pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['ZoneTagsToMatchArgs']]]] tags_to_matches: A set of tag keys and optional values for compute resource filtering:
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: ZoneArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        ## Example Usage
        ### S

        This is an example of how to create a zone resource.

        ```python
        import pulumi
        import pulumiverse_vra as vra

        this = vra.zone.Zone("this",
            description="my terraform test cloud zone",
            region_id=data["vra_region"]["this"]["id"],
            tags=[
                vra.zone.ZoneTagArgs(
                    key="my-tf-key",
                    value="my-tf-value",
                ),
                vra.zone.ZoneTagArgs(
                    key="tf-foo",
                    value="tf-bar",
                ),
            ])
        ```

        A zone resource supports the following arguments:

        :param str resource_name: The name of the resource.
        :param ZoneArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(ZoneArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 compute_ids: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 custom_properties: Optional[pulumi.Input[Mapping[str, Any]]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 folder: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 placement_policy: Optional[pulumi.Input[str]] = None,
                 region_id: Optional[pulumi.Input[str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['ZoneTagArgs']]]]] = None,
                 tags_to_matches: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['ZoneTagsToMatchArgs']]]]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = ZoneArgs.__new__(ZoneArgs)

            __props__.__dict__["compute_ids"] = compute_ids
            __props__.__dict__["custom_properties"] = custom_properties
            __props__.__dict__["description"] = description
            __props__.__dict__["folder"] = folder
            __props__.__dict__["name"] = name
            __props__.__dict__["placement_policy"] = placement_policy
            if region_id is None and not opts.urn:
                raise TypeError("Missing required property 'region_id'")
            __props__.__dict__["region_id"] = region_id
            __props__.__dict__["tags"] = tags
            __props__.__dict__["tags_to_matches"] = tags_to_matches
            __props__.__dict__["cloud_account_id"] = None
            __props__.__dict__["created_at"] = None
            __props__.__dict__["external_region_id"] = None
            __props__.__dict__["links"] = None
            __props__.__dict__["org_id"] = None
            __props__.__dict__["owner"] = None
            __props__.__dict__["updated_at"] = None
        super(Zone, __self__).__init__(
            'vra:zone/zone:Zone',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            cloud_account_id: Optional[pulumi.Input[str]] = None,
            compute_ids: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
            created_at: Optional[pulumi.Input[str]] = None,
            custom_properties: Optional[pulumi.Input[Mapping[str, Any]]] = None,
            description: Optional[pulumi.Input[str]] = None,
            external_region_id: Optional[pulumi.Input[str]] = None,
            folder: Optional[pulumi.Input[str]] = None,
            links: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['ZoneLinkArgs']]]]] = None,
            name: Optional[pulumi.Input[str]] = None,
            org_id: Optional[pulumi.Input[str]] = None,
            owner: Optional[pulumi.Input[str]] = None,
            placement_policy: Optional[pulumi.Input[str]] = None,
            region_id: Optional[pulumi.Input[str]] = None,
            tags: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['ZoneTagArgs']]]]] = None,
            tags_to_matches: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['ZoneTagsToMatchArgs']]]]] = None,
            updated_at: Optional[pulumi.Input[str]] = None) -> 'Zone':
        """
        Get an existing Zone resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] cloud_account_id: The ID of the cloud account this zone belongs to.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] compute_ids: The ids of the compute resources that will be explicitly assigned to this zone.
        :param pulumi.Input[str] created_at: Date when the entity was created. The date is in ISO 8601 and UTC.
        :param pulumi.Input[Mapping[str, Any]] custom_properties: A list of key value pair of properties that will be used.
        :param pulumi.Input[str] description: A human-friendly description.
        :param pulumi.Input[str] external_region_id: The id of the region for which this zone is defined.
        :param pulumi.Input[str] folder: The folder relative path to the datacenter where resources are deployed to (only applicable for vSphere cloud zones).
        :param pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['ZoneLinkArgs']]]] links: HATEOAS of entity.
        :param pulumi.Input[str] name: A human-friendly name used as an identifier for the zone resource instance.
        :param pulumi.Input[str] org_id: The id of the organization this entity belongs to.
        :param pulumi.Input[str] owner: Email of the user that owns the entity.
        :param pulumi.Input[str] placement_policy: The placement policy for the zone. One of `DEFAULT`, `SPREAD` or `BINPACK`. Default is `DEFAULT`.
        :param pulumi.Input[str] region_id: The id of the region for which this zone is created.
        :param pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['ZoneTagArgs']]]] tags: A set of tag keys and optional values that were set on this resource:
        :param pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['ZoneTagsToMatchArgs']]]] tags_to_matches: A set of tag keys and optional values for compute resource filtering:
        :param pulumi.Input[str] updated_at: Date when the entity was last updated. The date is ISO 8601 and UTC.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _ZoneState.__new__(_ZoneState)

        __props__.__dict__["cloud_account_id"] = cloud_account_id
        __props__.__dict__["compute_ids"] = compute_ids
        __props__.__dict__["created_at"] = created_at
        __props__.__dict__["custom_properties"] = custom_properties
        __props__.__dict__["description"] = description
        __props__.__dict__["external_region_id"] = external_region_id
        __props__.__dict__["folder"] = folder
        __props__.__dict__["links"] = links
        __props__.__dict__["name"] = name
        __props__.__dict__["org_id"] = org_id
        __props__.__dict__["owner"] = owner
        __props__.__dict__["placement_policy"] = placement_policy
        __props__.__dict__["region_id"] = region_id
        __props__.__dict__["tags"] = tags
        __props__.__dict__["tags_to_matches"] = tags_to_matches
        __props__.__dict__["updated_at"] = updated_at
        return Zone(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="cloudAccountId")
    def cloud_account_id(self) -> pulumi.Output[str]:
        """
        The ID of the cloud account this zone belongs to.
        """
        return pulumi.get(self, "cloud_account_id")

    @property
    @pulumi.getter(name="computeIds")
    def compute_ids(self) -> pulumi.Output[Sequence[str]]:
        """
        The ids of the compute resources that will be explicitly assigned to this zone.
        """
        return pulumi.get(self, "compute_ids")

    @property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> pulumi.Output[str]:
        """
        Date when the entity was created. The date is in ISO 8601 and UTC.
        """
        return pulumi.get(self, "created_at")

    @property
    @pulumi.getter(name="customProperties")
    def custom_properties(self) -> pulumi.Output[Mapping[str, Any]]:
        """
        A list of key value pair of properties that will be used.
        """
        return pulumi.get(self, "custom_properties")

    @property
    @pulumi.getter
    def description(self) -> pulumi.Output[Optional[str]]:
        """
        A human-friendly description.
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="externalRegionId")
    def external_region_id(self) -> pulumi.Output[str]:
        """
        The id of the region for which this zone is defined.
        """
        return pulumi.get(self, "external_region_id")

    @property
    @pulumi.getter
    def folder(self) -> pulumi.Output[Optional[str]]:
        """
        The folder relative path to the datacenter where resources are deployed to (only applicable for vSphere cloud zones).
        """
        return pulumi.get(self, "folder")

    @property
    @pulumi.getter
    def links(self) -> pulumi.Output[Sequence['outputs.ZoneLink']]:
        """
        HATEOAS of entity.
        """
        return pulumi.get(self, "links")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[str]:
        """
        A human-friendly name used as an identifier for the zone resource instance.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="orgId")
    def org_id(self) -> pulumi.Output[str]:
        """
        The id of the organization this entity belongs to.
        """
        return pulumi.get(self, "org_id")

    @property
    @pulumi.getter
    def owner(self) -> pulumi.Output[str]:
        """
        Email of the user that owns the entity.
        """
        return pulumi.get(self, "owner")

    @property
    @pulumi.getter(name="placementPolicy")
    def placement_policy(self) -> pulumi.Output[Optional[str]]:
        """
        The placement policy for the zone. One of `DEFAULT`, `SPREAD` or `BINPACK`. Default is `DEFAULT`.
        """
        return pulumi.get(self, "placement_policy")

    @property
    @pulumi.getter(name="regionId")
    def region_id(self) -> pulumi.Output[str]:
        """
        The id of the region for which this zone is created.
        """
        return pulumi.get(self, "region_id")

    @property
    @pulumi.getter
    def tags(self) -> pulumi.Output[Sequence['outputs.ZoneTag']]:
        """
        A set of tag keys and optional values that were set on this resource:
        """
        return pulumi.get(self, "tags")

    @property
    @pulumi.getter(name="tagsToMatches")
    def tags_to_matches(self) -> pulumi.Output[Sequence['outputs.ZoneTagsToMatch']]:
        """
        A set of tag keys and optional values for compute resource filtering:
        """
        return pulumi.get(self, "tags_to_matches")

    @property
    @pulumi.getter(name="updatedAt")
    def updated_at(self) -> pulumi.Output[str]:
        """
        Date when the entity was last updated. The date is ISO 8601 and UTC.
        """
        return pulumi.get(self, "updated_at")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = [
    'GetSecurityGroupResult',
    'AwaitableGetSecurityGroupResult',
    'get_security_group',
    'get_security_group_output',
]

@pulumi.output_type
class GetSecurityGroupResult:
    """
    A collection of values returned by getSecurityGroup.
    """
    def __init__(__self__, created_at=None, description=None, external_id=None, external_region_id=None, filter=None, id=None, links=None, name=None, organization_id=None, owner=None, rules=None, updated_at=None):
        if created_at and not isinstance(created_at, str):
            raise TypeError("Expected argument 'created_at' to be a str")
        pulumi.set(__self__, "created_at", created_at)
        if description and not isinstance(description, str):
            raise TypeError("Expected argument 'description' to be a str")
        pulumi.set(__self__, "description", description)
        if external_id and not isinstance(external_id, str):
            raise TypeError("Expected argument 'external_id' to be a str")
        pulumi.set(__self__, "external_id", external_id)
        if external_region_id and not isinstance(external_region_id, str):
            raise TypeError("Expected argument 'external_region_id' to be a str")
        pulumi.set(__self__, "external_region_id", external_region_id)
        if filter and not isinstance(filter, str):
            raise TypeError("Expected argument 'filter' to be a str")
        pulumi.set(__self__, "filter", filter)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if links and not isinstance(links, list):
            raise TypeError("Expected argument 'links' to be a list")
        pulumi.set(__self__, "links", links)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if organization_id and not isinstance(organization_id, str):
            raise TypeError("Expected argument 'organization_id' to be a str")
        pulumi.set(__self__, "organization_id", organization_id)
        if owner and not isinstance(owner, str):
            raise TypeError("Expected argument 'owner' to be a str")
        pulumi.set(__self__, "owner", owner)
        if rules and not isinstance(rules, list):
            raise TypeError("Expected argument 'rules' to be a list")
        pulumi.set(__self__, "rules", rules)
        if updated_at and not isinstance(updated_at, str):
            raise TypeError("Expected argument 'updated_at' to be a str")
        pulumi.set(__self__, "updated_at", updated_at)

    @property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> str:
        """
        Date when the entity was created. The date is in ISO 6801 and UTC.
        """
        return pulumi.get(self, "created_at")

    @property
    @pulumi.getter
    def description(self) -> str:
        """
        A human-friendly description of the security groups.
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="externalId")
    def external_id(self) -> str:
        """
        External entity Id on the provider side.
        """
        return pulumi.get(self, "external_id")

    @property
    @pulumi.getter(name="externalRegionId")
    def external_region_id(self) -> str:
        """
        The id of the region for which this entity is defined.
        """
        return pulumi.get(self, "external_region_id")

    @property
    @pulumi.getter
    def filter(self) -> str:
        return pulumi.get(self, "filter")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        ID of the security group.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def links(self) -> Sequence['outputs.GetSecurityGroupLinkResult']:
        """
        HATEOAS of the entity
        """
        return pulumi.get(self, "links")

    @property
    @pulumi.getter
    def name(self) -> str:
        """
        Name of the security group.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="organizationId")
    def organization_id(self) -> str:
        """
        ID of organization that entity belongs to.
        """
        return pulumi.get(self, "organization_id")

    @property
    @pulumi.getter
    def owner(self) -> str:
        return pulumi.get(self, "owner")

    @property
    @pulumi.getter
    def rules(self) -> Optional[Sequence['outputs.GetSecurityGroupRuleResult']]:
        """
        List of security rules.
        """
        return pulumi.get(self, "rules")

    @property
    @pulumi.getter(name="updatedAt")
    def updated_at(self) -> str:
        """
        Date when the entity was last updated. The date is ISO 8601 and UTC.
        """
        return pulumi.get(self, "updated_at")


class AwaitableGetSecurityGroupResult(GetSecurityGroupResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetSecurityGroupResult(
            created_at=self.created_at,
            description=self.description,
            external_id=self.external_id,
            external_region_id=self.external_region_id,
            filter=self.filter,
            id=self.id,
            links=self.links,
            name=self.name,
            organization_id=self.organization_id,
            owner=self.owner,
            rules=self.rules,
            updated_at=self.updated_at)


def get_security_group(filter: Optional[str] = None,
                       rules: Optional[Sequence[pulumi.InputType['GetSecurityGroupRuleArgs']]] = None,
                       opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetSecurityGroupResult:
    """
    ## Example Usage
    ### S
    This is an example of how to lookup security groups.

    **Security groups by filter query:**

    ```python
    import pulumi
    import pulumi_vra as vra

    this = vra.securitygroup.get_security_group(filter=f"name eq '{var['name']}'")
    ```

    A Security group supports the following arguments:


    :param str filter: Search criteria to narrow down the Security groups.
    :param Sequence[pulumi.InputType['GetSecurityGroupRuleArgs']] rules: List of security rules.
    """
    __args__ = dict()
    __args__['filter'] = filter
    __args__['rules'] = rules
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('vra:securitygroup/getSecurityGroup:getSecurityGroup', __args__, opts=opts, typ=GetSecurityGroupResult).value

    return AwaitableGetSecurityGroupResult(
        created_at=__ret__.created_at,
        description=__ret__.description,
        external_id=__ret__.external_id,
        external_region_id=__ret__.external_region_id,
        filter=__ret__.filter,
        id=__ret__.id,
        links=__ret__.links,
        name=__ret__.name,
        organization_id=__ret__.organization_id,
        owner=__ret__.owner,
        rules=__ret__.rules,
        updated_at=__ret__.updated_at)


@_utilities.lift_output_func(get_security_group)
def get_security_group_output(filter: Optional[pulumi.Input[str]] = None,
                              rules: Optional[pulumi.Input[Optional[Sequence[pulumi.InputType['GetSecurityGroupRuleArgs']]]]] = None,
                              opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetSecurityGroupResult]:
    """
    ## Example Usage
    ### S
    This is an example of how to lookup security groups.

    **Security groups by filter query:**

    ```python
    import pulumi
    import pulumi_vra as vra

    this = vra.securitygroup.get_security_group(filter=f"name eq '{var['name']}'")
    ```

    A Security group supports the following arguments:


    :param str filter: Search criteria to narrow down the Security groups.
    :param Sequence[pulumi.InputType['GetSecurityGroupRuleArgs']] rules: List of security rules.
    """
    ...



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = [
    'GetBlockDeviceResult',
    'AwaitableGetBlockDeviceResult',
    'get_block_device',
    'get_block_device_output',
]

@pulumi.output_type
class GetBlockDeviceResult:
    """
    A collection of values returned by getBlockDevice.
    """
    def __init__(__self__, capacity_in_gb=None, cloud_account_ids=None, created_at=None, custom_properties=None, deployment_id=None, description=None, expand_snapshots=None, external_id=None, external_region_id=None, external_zone_id=None, filter=None, id=None, links=None, name=None, org_id=None, owner=None, persistent=None, project_id=None, snapshots=None, status=None, tags=None, updated_at=None):
        if capacity_in_gb and not isinstance(capacity_in_gb, int):
            raise TypeError("Expected argument 'capacity_in_gb' to be a int")
        pulumi.set(__self__, "capacity_in_gb", capacity_in_gb)
        if cloud_account_ids and not isinstance(cloud_account_ids, list):
            raise TypeError("Expected argument 'cloud_account_ids' to be a list")
        pulumi.set(__self__, "cloud_account_ids", cloud_account_ids)
        if created_at and not isinstance(created_at, str):
            raise TypeError("Expected argument 'created_at' to be a str")
        pulumi.set(__self__, "created_at", created_at)
        if custom_properties and not isinstance(custom_properties, dict):
            raise TypeError("Expected argument 'custom_properties' to be a dict")
        pulumi.set(__self__, "custom_properties", custom_properties)
        if deployment_id and not isinstance(deployment_id, str):
            raise TypeError("Expected argument 'deployment_id' to be a str")
        pulumi.set(__self__, "deployment_id", deployment_id)
        if description and not isinstance(description, str):
            raise TypeError("Expected argument 'description' to be a str")
        pulumi.set(__self__, "description", description)
        if expand_snapshots and not isinstance(expand_snapshots, bool):
            raise TypeError("Expected argument 'expand_snapshots' to be a bool")
        pulumi.set(__self__, "expand_snapshots", expand_snapshots)
        if external_id and not isinstance(external_id, str):
            raise TypeError("Expected argument 'external_id' to be a str")
        pulumi.set(__self__, "external_id", external_id)
        if external_region_id and not isinstance(external_region_id, str):
            raise TypeError("Expected argument 'external_region_id' to be a str")
        pulumi.set(__self__, "external_region_id", external_region_id)
        if external_zone_id and not isinstance(external_zone_id, str):
            raise TypeError("Expected argument 'external_zone_id' to be a str")
        pulumi.set(__self__, "external_zone_id", external_zone_id)
        if filter and not isinstance(filter, str):
            raise TypeError("Expected argument 'filter' to be a str")
        pulumi.set(__self__, "filter", filter)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if links and not isinstance(links, list):
            raise TypeError("Expected argument 'links' to be a list")
        pulumi.set(__self__, "links", links)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if org_id and not isinstance(org_id, str):
            raise TypeError("Expected argument 'org_id' to be a str")
        pulumi.set(__self__, "org_id", org_id)
        if owner and not isinstance(owner, str):
            raise TypeError("Expected argument 'owner' to be a str")
        pulumi.set(__self__, "owner", owner)
        if persistent and not isinstance(persistent, bool):
            raise TypeError("Expected argument 'persistent' to be a bool")
        pulumi.set(__self__, "persistent", persistent)
        if project_id and not isinstance(project_id, str):
            raise TypeError("Expected argument 'project_id' to be a str")
        pulumi.set(__self__, "project_id", project_id)
        if snapshots and not isinstance(snapshots, list):
            raise TypeError("Expected argument 'snapshots' to be a list")
        pulumi.set(__self__, "snapshots", snapshots)
        if status and not isinstance(status, str):
            raise TypeError("Expected argument 'status' to be a str")
        pulumi.set(__self__, "status", status)
        if tags and not isinstance(tags, list):
            raise TypeError("Expected argument 'tags' to be a list")
        pulumi.set(__self__, "tags", tags)
        if updated_at and not isinstance(updated_at, str):
            raise TypeError("Expected argument 'updated_at' to be a str")
        pulumi.set(__self__, "updated_at", updated_at)

    @property
    @pulumi.getter(name="capacityInGb")
    def capacity_in_gb(self) -> int:
        """
        Capacity of the block device in GB.
        """
        return pulumi.get(self, "capacity_in_gb")

    @property
    @pulumi.getter(name="cloudAccountIds")
    def cloud_account_ids(self) -> Sequence[str]:
        """
        Set of ids of the cloud accounts this entity belongs to.
        """
        return pulumi.get(self, "cloud_account_ids")

    @property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> str:
        """
        Date when the entity was created. The date is in ISO 6801 and UTC.
        """
        return pulumi.get(self, "created_at")

    @property
    @pulumi.getter(name="customProperties")
    def custom_properties(self) -> Mapping[str, Any]:
        """
        Additional custom properties that may be used to extend the machine.
        """
        return pulumi.get(self, "custom_properties")

    @property
    @pulumi.getter(name="deploymentId")
    def deployment_id(self) -> str:
        """
        The id of the deployment that is associated with this resource.
        """
        return pulumi.get(self, "deployment_id")

    @property
    @pulumi.getter
    def description(self) -> Optional[str]:
        """
        Describes machine within the scope of your organization and is not propagated to the cloud.
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="expandSnapshots")
    def expand_snapshots(self) -> Optional[bool]:
        return pulumi.get(self, "expand_snapshots")

    @property
    @pulumi.getter(name="externalId")
    def external_id(self) -> str:
        """
        External entity Id on the provider side.
        """
        return pulumi.get(self, "external_id")

    @property
    @pulumi.getter(name="externalRegionId")
    def external_region_id(self) -> str:
        """
        The external regionId of the resource.
        """
        return pulumi.get(self, "external_region_id")

    @property
    @pulumi.getter(name="externalZoneId")
    def external_zone_id(self) -> str:
        """
        The external zoneId of the resource.
        """
        return pulumi.get(self, "external_zone_id")

    @property
    @pulumi.getter
    def filter(self) -> Optional[str]:
        return pulumi.get(self, "filter")

    @property
    @pulumi.getter
    def id(self) -> str:
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def links(self) -> Sequence['outputs.GetBlockDeviceLinkResult']:
        """
        HATEOAS of the entity.
        """
        return pulumi.get(self, "links")

    @property
    @pulumi.getter
    def name(self) -> str:
        """
        A human-friendly name used as an identifier in APIs that support this option.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="orgId")
    def org_id(self) -> str:
        """
        The id of the organization this entity belongs to.
        """
        return pulumi.get(self, "org_id")

    @property
    @pulumi.getter
    def owner(self) -> str:
        """
        Email of the user that owns the entity.
        """
        return pulumi.get(self, "owner")

    @property
    @pulumi.getter
    def persistent(self) -> bool:
        """
        Indicates whether the block device survives a delete action.
        """
        return pulumi.get(self, "persistent")

    @property
    @pulumi.getter(name="projectId")
    def project_id(self) -> str:
        """
        The id of the project the current user belongs to.
        """
        return pulumi.get(self, "project_id")

    @property
    @pulumi.getter
    def snapshots(self) -> Sequence['outputs.GetBlockDeviceSnapshotResult']:
        return pulumi.get(self, "snapshots")

    @property
    @pulumi.getter
    def status(self) -> str:
        """
        Status of the block device.
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter
    def tags(self) -> Sequence['outputs.GetBlockDeviceTagResult']:
        """
        A set of tag keys and optional values that were set on this resource instance.
        example:[ { "key" : "vmware.enumeration.type", "value": "nebs_block" } ]
        """
        return pulumi.get(self, "tags")

    @property
    @pulumi.getter(name="updatedAt")
    def updated_at(self) -> str:
        """
        Date when the entity was last updated. The date is ISO 8601 and UTC.
        """
        return pulumi.get(self, "updated_at")


class AwaitableGetBlockDeviceResult(GetBlockDeviceResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetBlockDeviceResult(
            capacity_in_gb=self.capacity_in_gb,
            cloud_account_ids=self.cloud_account_ids,
            created_at=self.created_at,
            custom_properties=self.custom_properties,
            deployment_id=self.deployment_id,
            description=self.description,
            expand_snapshots=self.expand_snapshots,
            external_id=self.external_id,
            external_region_id=self.external_region_id,
            external_zone_id=self.external_zone_id,
            filter=self.filter,
            id=self.id,
            links=self.links,
            name=self.name,
            org_id=self.org_id,
            owner=self.owner,
            persistent=self.persistent,
            project_id=self.project_id,
            snapshots=self.snapshots,
            status=self.status,
            tags=self.tags,
            updated_at=self.updated_at)


def get_block_device(description: Optional[str] = None,
                     expand_snapshots: Optional[bool] = None,
                     filter: Optional[str] = None,
                     id: Optional[str] = None,
                     tags: Optional[Sequence[pulumi.InputType['GetBlockDeviceTagArgs']]] = None,
                     opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetBlockDeviceResult:
    """
    ## ---layout: "vra"

    page_title: "VMware vRealize Automation: blockdevice.BlockDevice"
    description: |-
      Provides a data lookup for vra_block_device.
    ---

    # Data Source: blockdevice.BlockDevice

    Provides a data lookup for a vra_block_device.

    ## Example Usage
    ### S

    **Block device data source by its id:**

    This is an example of how to read a block device data source using its ID.

    ```python
    import pulumi
    import pulumi_vra as vra

    this = vra.blockdevice.get_block_device(id=var["block_device_id"])
    ```

    **Block device data source filter by name:**

    This is an example of how to read a block device data source using its name.

    ```python
    import pulumi
    import pulumi_vra as vra

    this = vra.blockdevice.get_block_device(filter=f"name eq '{var['block_device_name']}'")
    ```


    :param str description: Describes machine within the scope of your organization and is not propagated to the cloud.
    :param bool expand_snapshots: Indicates whether the snapshots of the block-devices should be included in the state. Applicable only for first class block devices.
    :param str filter: Search criteria to filter the list of block devices.
    :param str id: The id of the block device.
    :param Sequence[pulumi.InputType['GetBlockDeviceTagArgs']] tags: A set of tag keys and optional values that were set on this resource instance.
           example:[ { "key" : "vmware.enumeration.type", "value": "nebs_block" } ]
    """
    __args__ = dict()
    __args__['description'] = description
    __args__['expandSnapshots'] = expand_snapshots
    __args__['filter'] = filter
    __args__['id'] = id
    __args__['tags'] = tags
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('vra:blockdevice/getBlockDevice:getBlockDevice', __args__, opts=opts, typ=GetBlockDeviceResult).value

    return AwaitableGetBlockDeviceResult(
        capacity_in_gb=__ret__.capacity_in_gb,
        cloud_account_ids=__ret__.cloud_account_ids,
        created_at=__ret__.created_at,
        custom_properties=__ret__.custom_properties,
        deployment_id=__ret__.deployment_id,
        description=__ret__.description,
        expand_snapshots=__ret__.expand_snapshots,
        external_id=__ret__.external_id,
        external_region_id=__ret__.external_region_id,
        external_zone_id=__ret__.external_zone_id,
        filter=__ret__.filter,
        id=__ret__.id,
        links=__ret__.links,
        name=__ret__.name,
        org_id=__ret__.org_id,
        owner=__ret__.owner,
        persistent=__ret__.persistent,
        project_id=__ret__.project_id,
        snapshots=__ret__.snapshots,
        status=__ret__.status,
        tags=__ret__.tags,
        updated_at=__ret__.updated_at)


@_utilities.lift_output_func(get_block_device)
def get_block_device_output(description: Optional[pulumi.Input[Optional[str]]] = None,
                            expand_snapshots: Optional[pulumi.Input[Optional[bool]]] = None,
                            filter: Optional[pulumi.Input[Optional[str]]] = None,
                            id: Optional[pulumi.Input[Optional[str]]] = None,
                            tags: Optional[pulumi.Input[Optional[Sequence[pulumi.InputType['GetBlockDeviceTagArgs']]]]] = None,
                            opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetBlockDeviceResult]:
    """
    ## ---layout: "vra"

    page_title: "VMware vRealize Automation: blockdevice.BlockDevice"
    description: |-
      Provides a data lookup for vra_block_device.
    ---

    # Data Source: blockdevice.BlockDevice

    Provides a data lookup for a vra_block_device.

    ## Example Usage
    ### S

    **Block device data source by its id:**

    This is an example of how to read a block device data source using its ID.

    ```python
    import pulumi
    import pulumi_vra as vra

    this = vra.blockdevice.get_block_device(id=var["block_device_id"])
    ```

    **Block device data source filter by name:**

    This is an example of how to read a block device data source using its name.

    ```python
    import pulumi
    import pulumi_vra as vra

    this = vra.blockdevice.get_block_device(filter=f"name eq '{var['block_device_name']}'")
    ```


    :param str description: Describes machine within the scope of your organization and is not propagated to the cloud.
    :param bool expand_snapshots: Indicates whether the snapshots of the block-devices should be included in the state. Applicable only for first class block devices.
    :param str filter: Search criteria to filter the list of block devices.
    :param str id: The id of the block device.
    :param Sequence[pulumi.InputType['GetBlockDeviceTagArgs']] tags: A set of tag keys and optional values that were set on this resource instance.
           example:[ { "key" : "vmware.enumeration.type", "value": "nebs_block" } ]
    """
    ...



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['AzureArgs', 'Azure']

@pulumi.input_type
class AzureArgs:
    def __init__(__self__, *,
                 default_item: pulumi.Input[bool],
                 region_id: pulumi.Input[str],
                 data_disk_caching: Optional[pulumi.Input[str]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 disk_type: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 os_disk_caching: Optional[pulumi.Input[str]] = None,
                 storage_account_id: Optional[pulumi.Input[str]] = None,
                 supports_encryption: Optional[pulumi.Input[bool]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input['AzureTagArgs']]]] = None):
        """
        The set of arguments for constructing a Azure resource.
        :param pulumi.Input[bool] default_item: Indicates if this storage profile is a default profile.
        :param pulumi.Input[str] region_id: A link to the region that is associated with the storage profile.
        :param pulumi.Input[str] data_disk_caching: Indicates the caching mechanism for additional disk.
        :param pulumi.Input[str] description: A human-friendly description.
        :param pulumi.Input[str] disk_type: Indicates the performance tier for the storage type. Premium disks are SSD backed and Standard disks are HDD backed.
        :param pulumi.Input[str] name: A human-friendly name used as an identifier in APIs that support this option.
        :param pulumi.Input[str] os_disk_caching: Indicates the caching mechanism for OS disk. Default policy for OS disks is Read/Write.
        :param pulumi.Input[str] storage_account_id: Id of a storage account where in the disk is placed.
        :param pulumi.Input[bool] supports_encryption: Indicates whether this storage policy should support encryption or not.
        :param pulumi.Input[Sequence[pulumi.Input['AzureTagArgs']]] tags: A set of tag keys and optional values that were set on this Network Profile.
               example:[ { "key" : "ownedBy", "value": "Rainpole" } ]
        """
        pulumi.set(__self__, "default_item", default_item)
        pulumi.set(__self__, "region_id", region_id)
        if data_disk_caching is not None:
            pulumi.set(__self__, "data_disk_caching", data_disk_caching)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if disk_type is not None:
            pulumi.set(__self__, "disk_type", disk_type)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if os_disk_caching is not None:
            pulumi.set(__self__, "os_disk_caching", os_disk_caching)
        if storage_account_id is not None:
            pulumi.set(__self__, "storage_account_id", storage_account_id)
        if supports_encryption is not None:
            pulumi.set(__self__, "supports_encryption", supports_encryption)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)

    @property
    @pulumi.getter(name="defaultItem")
    def default_item(self) -> pulumi.Input[bool]:
        """
        Indicates if this storage profile is a default profile.
        """
        return pulumi.get(self, "default_item")

    @default_item.setter
    def default_item(self, value: pulumi.Input[bool]):
        pulumi.set(self, "default_item", value)

    @property
    @pulumi.getter(name="regionId")
    def region_id(self) -> pulumi.Input[str]:
        """
        A link to the region that is associated with the storage profile.
        """
        return pulumi.get(self, "region_id")

    @region_id.setter
    def region_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "region_id", value)

    @property
    @pulumi.getter(name="dataDiskCaching")
    def data_disk_caching(self) -> Optional[pulumi.Input[str]]:
        """
        Indicates the caching mechanism for additional disk.
        """
        return pulumi.get(self, "data_disk_caching")

    @data_disk_caching.setter
    def data_disk_caching(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "data_disk_caching", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[str]]:
        """
        A human-friendly description.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="diskType")
    def disk_type(self) -> Optional[pulumi.Input[str]]:
        """
        Indicates the performance tier for the storage type. Premium disks are SSD backed and Standard disks are HDD backed.
        """
        return pulumi.get(self, "disk_type")

    @disk_type.setter
    def disk_type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "disk_type", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        A human-friendly name used as an identifier in APIs that support this option.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="osDiskCaching")
    def os_disk_caching(self) -> Optional[pulumi.Input[str]]:
        """
        Indicates the caching mechanism for OS disk. Default policy for OS disks is Read/Write.
        """
        return pulumi.get(self, "os_disk_caching")

    @os_disk_caching.setter
    def os_disk_caching(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "os_disk_caching", value)

    @property
    @pulumi.getter(name="storageAccountId")
    def storage_account_id(self) -> Optional[pulumi.Input[str]]:
        """
        Id of a storage account where in the disk is placed.
        """
        return pulumi.get(self, "storage_account_id")

    @storage_account_id.setter
    def storage_account_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "storage_account_id", value)

    @property
    @pulumi.getter(name="supportsEncryption")
    def supports_encryption(self) -> Optional[pulumi.Input[bool]]:
        """
        Indicates whether this storage policy should support encryption or not.
        """
        return pulumi.get(self, "supports_encryption")

    @supports_encryption.setter
    def supports_encryption(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "supports_encryption", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['AzureTagArgs']]]]:
        """
        A set of tag keys and optional values that were set on this Network Profile.
        example:[ { "key" : "ownedBy", "value": "Rainpole" } ]
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['AzureTagArgs']]]]):
        pulumi.set(self, "tags", value)


@pulumi.input_type
class _AzureState:
    def __init__(__self__, *,
                 created_at: Optional[pulumi.Input[str]] = None,
                 data_disk_caching: Optional[pulumi.Input[str]] = None,
                 default_item: Optional[pulumi.Input[bool]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 disk_type: Optional[pulumi.Input[str]] = None,
                 external_region_id: Optional[pulumi.Input[str]] = None,
                 links: Optional[pulumi.Input[Sequence[pulumi.Input['AzureLinkArgs']]]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 organization_id: Optional[pulumi.Input[str]] = None,
                 os_disk_caching: Optional[pulumi.Input[str]] = None,
                 owner: Optional[pulumi.Input[str]] = None,
                 region_id: Optional[pulumi.Input[str]] = None,
                 storage_account_id: Optional[pulumi.Input[str]] = None,
                 supports_encryption: Optional[pulumi.Input[bool]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input['AzureTagArgs']]]] = None,
                 updated_at: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering Azure resources.
        :param pulumi.Input[str] created_at: Date when the entity was created. The date is in ISO 6801 and UTC.
        :param pulumi.Input[str] data_disk_caching: Indicates the caching mechanism for additional disk.
        :param pulumi.Input[bool] default_item: Indicates if this storage profile is a default profile.
        :param pulumi.Input[str] description: A human-friendly description.
        :param pulumi.Input[str] disk_type: Indicates the performance tier for the storage type. Premium disks are SSD backed and Standard disks are HDD backed.
        :param pulumi.Input[str] external_region_id: The id of the region as seen in the cloud provider for which this profile is defined.
        :param pulumi.Input[Sequence[pulumi.Input['AzureLinkArgs']]] links: HATEOAS of the entity
        :param pulumi.Input[str] name: A human-friendly name used as an identifier in APIs that support this option.
        :param pulumi.Input[str] organization_id: The id of the organization this entity belongs to.
        :param pulumi.Input[str] os_disk_caching: Indicates the caching mechanism for OS disk. Default policy for OS disks is Read/Write.
        :param pulumi.Input[str] owner: Email of the user that owns the entity.
        :param pulumi.Input[str] region_id: A link to the region that is associated with the storage profile.
        :param pulumi.Input[str] storage_account_id: Id of a storage account where in the disk is placed.
        :param pulumi.Input[bool] supports_encryption: Indicates whether this storage policy should support encryption or not.
        :param pulumi.Input[Sequence[pulumi.Input['AzureTagArgs']]] tags: A set of tag keys and optional values that were set on this Network Profile.
               example:[ { "key" : "ownedBy", "value": "Rainpole" } ]
        :param pulumi.Input[str] updated_at: Date when the entity was last updated. The date is ISO 8601 and UTC.
        """
        if created_at is not None:
            pulumi.set(__self__, "created_at", created_at)
        if data_disk_caching is not None:
            pulumi.set(__self__, "data_disk_caching", data_disk_caching)
        if default_item is not None:
            pulumi.set(__self__, "default_item", default_item)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if disk_type is not None:
            pulumi.set(__self__, "disk_type", disk_type)
        if external_region_id is not None:
            pulumi.set(__self__, "external_region_id", external_region_id)
        if links is not None:
            pulumi.set(__self__, "links", links)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if organization_id is not None:
            pulumi.set(__self__, "organization_id", organization_id)
        if os_disk_caching is not None:
            pulumi.set(__self__, "os_disk_caching", os_disk_caching)
        if owner is not None:
            pulumi.set(__self__, "owner", owner)
        if region_id is not None:
            pulumi.set(__self__, "region_id", region_id)
        if storage_account_id is not None:
            pulumi.set(__self__, "storage_account_id", storage_account_id)
        if supports_encryption is not None:
            pulumi.set(__self__, "supports_encryption", supports_encryption)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)
        if updated_at is not None:
            pulumi.set(__self__, "updated_at", updated_at)

    @property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> Optional[pulumi.Input[str]]:
        """
        Date when the entity was created. The date is in ISO 6801 and UTC.
        """
        return pulumi.get(self, "created_at")

    @created_at.setter
    def created_at(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "created_at", value)

    @property
    @pulumi.getter(name="dataDiskCaching")
    def data_disk_caching(self) -> Optional[pulumi.Input[str]]:
        """
        Indicates the caching mechanism for additional disk.
        """
        return pulumi.get(self, "data_disk_caching")

    @data_disk_caching.setter
    def data_disk_caching(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "data_disk_caching", value)

    @property
    @pulumi.getter(name="defaultItem")
    def default_item(self) -> Optional[pulumi.Input[bool]]:
        """
        Indicates if this storage profile is a default profile.
        """
        return pulumi.get(self, "default_item")

    @default_item.setter
    def default_item(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "default_item", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[str]]:
        """
        A human-friendly description.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="diskType")
    def disk_type(self) -> Optional[pulumi.Input[str]]:
        """
        Indicates the performance tier for the storage type. Premium disks are SSD backed and Standard disks are HDD backed.
        """
        return pulumi.get(self, "disk_type")

    @disk_type.setter
    def disk_type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "disk_type", value)

    @property
    @pulumi.getter(name="externalRegionId")
    def external_region_id(self) -> Optional[pulumi.Input[str]]:
        """
        The id of the region as seen in the cloud provider for which this profile is defined.
        """
        return pulumi.get(self, "external_region_id")

    @external_region_id.setter
    def external_region_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "external_region_id", value)

    @property
    @pulumi.getter
    def links(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['AzureLinkArgs']]]]:
        """
        HATEOAS of the entity
        """
        return pulumi.get(self, "links")

    @links.setter
    def links(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['AzureLinkArgs']]]]):
        pulumi.set(self, "links", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        A human-friendly name used as an identifier in APIs that support this option.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="organizationId")
    def organization_id(self) -> Optional[pulumi.Input[str]]:
        """
        The id of the organization this entity belongs to.
        """
        return pulumi.get(self, "organization_id")

    @organization_id.setter
    def organization_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "organization_id", value)

    @property
    @pulumi.getter(name="osDiskCaching")
    def os_disk_caching(self) -> Optional[pulumi.Input[str]]:
        """
        Indicates the caching mechanism for OS disk. Default policy for OS disks is Read/Write.
        """
        return pulumi.get(self, "os_disk_caching")

    @os_disk_caching.setter
    def os_disk_caching(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "os_disk_caching", value)

    @property
    @pulumi.getter
    def owner(self) -> Optional[pulumi.Input[str]]:
        """
        Email of the user that owns the entity.
        """
        return pulumi.get(self, "owner")

    @owner.setter
    def owner(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "owner", value)

    @property
    @pulumi.getter(name="regionId")
    def region_id(self) -> Optional[pulumi.Input[str]]:
        """
        A link to the region that is associated with the storage profile.
        """
        return pulumi.get(self, "region_id")

    @region_id.setter
    def region_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "region_id", value)

    @property
    @pulumi.getter(name="storageAccountId")
    def storage_account_id(self) -> Optional[pulumi.Input[str]]:
        """
        Id of a storage account where in the disk is placed.
        """
        return pulumi.get(self, "storage_account_id")

    @storage_account_id.setter
    def storage_account_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "storage_account_id", value)

    @property
    @pulumi.getter(name="supportsEncryption")
    def supports_encryption(self) -> Optional[pulumi.Input[bool]]:
        """
        Indicates whether this storage policy should support encryption or not.
        """
        return pulumi.get(self, "supports_encryption")

    @supports_encryption.setter
    def supports_encryption(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "supports_encryption", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['AzureTagArgs']]]]:
        """
        A set of tag keys and optional values that were set on this Network Profile.
        example:[ { "key" : "ownedBy", "value": "Rainpole" } ]
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['AzureTagArgs']]]]):
        pulumi.set(self, "tags", value)

    @property
    @pulumi.getter(name="updatedAt")
    def updated_at(self) -> Optional[pulumi.Input[str]]:
        """
        Date when the entity was last updated. The date is ISO 8601 and UTC.
        """
        return pulumi.get(self, "updated_at")

    @updated_at.setter
    def updated_at(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "updated_at", value)


class Azure(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 data_disk_caching: Optional[pulumi.Input[str]] = None,
                 default_item: Optional[pulumi.Input[bool]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 disk_type: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 os_disk_caching: Optional[pulumi.Input[str]] = None,
                 region_id: Optional[pulumi.Input[str]] = None,
                 storage_account_id: Optional[pulumi.Input[str]] = None,
                 supports_encryption: Optional[pulumi.Input[bool]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['AzureTagArgs']]]]] = None,
                 __props__=None):
        """
        ## Example Usage
        ### S
        This is an example of how to create a storage profile azure resource.

        **Vra storage profile azure:**

        ```python
        import pulumi
        import pulumiverse_vra as vra

        # Azure storage profile using vra_storage_profile_azure resource with managed disk.
        this_azure = vra.storageprofile.Azure("thisAzure",
            description="Azure Storage Profile with managed disks.",
            region_id=data["vra_region"]["this"]["id"],
            default_item=False,
            supports_encryption=False,
            data_disk_caching="None",
            disk_type="Standard_LRS",
            os_disk_caching="None",
            tags=[vra.storageprofile.AzureTagArgs(
                key="foo",
                value="bar",
            )])
        # Azure storage profile using vra_storage_profile_azure resource with unmanaged disk.
        this_storageprofile_azure_azure = vra.storageprofile.Azure("thisStorageprofile/azureAzure",
            description="Azure Storage Profile with unmanaged disks.",
            region_id=data["vra_region"]["this"]["id"],
            default_item=False,
            supports_encryption=False,
            data_disk_caching="None",
            os_disk_caching="None",
            tags=[vra.storageprofile.AzureTagArgs(
                key="foo",
                value="bar",
            )])
        ```

        A storage profile azure resource supports the following arguments:

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] data_disk_caching: Indicates the caching mechanism for additional disk.
        :param pulumi.Input[bool] default_item: Indicates if this storage profile is a default profile.
        :param pulumi.Input[str] description: A human-friendly description.
        :param pulumi.Input[str] disk_type: Indicates the performance tier for the storage type. Premium disks are SSD backed and Standard disks are HDD backed.
        :param pulumi.Input[str] name: A human-friendly name used as an identifier in APIs that support this option.
        :param pulumi.Input[str] os_disk_caching: Indicates the caching mechanism for OS disk. Default policy for OS disks is Read/Write.
        :param pulumi.Input[str] region_id: A link to the region that is associated with the storage profile.
        :param pulumi.Input[str] storage_account_id: Id of a storage account where in the disk is placed.
        :param pulumi.Input[bool] supports_encryption: Indicates whether this storage policy should support encryption or not.
        :param pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['AzureTagArgs']]]] tags: A set of tag keys and optional values that were set on this Network Profile.
               example:[ { "key" : "ownedBy", "value": "Rainpole" } ]
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: AzureArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        ## Example Usage
        ### S
        This is an example of how to create a storage profile azure resource.

        **Vra storage profile azure:**

        ```python
        import pulumi
        import pulumiverse_vra as vra

        # Azure storage profile using vra_storage_profile_azure resource with managed disk.
        this_azure = vra.storageprofile.Azure("thisAzure",
            description="Azure Storage Profile with managed disks.",
            region_id=data["vra_region"]["this"]["id"],
            default_item=False,
            supports_encryption=False,
            data_disk_caching="None",
            disk_type="Standard_LRS",
            os_disk_caching="None",
            tags=[vra.storageprofile.AzureTagArgs(
                key="foo",
                value="bar",
            )])
        # Azure storage profile using vra_storage_profile_azure resource with unmanaged disk.
        this_storageprofile_azure_azure = vra.storageprofile.Azure("thisStorageprofile/azureAzure",
            description="Azure Storage Profile with unmanaged disks.",
            region_id=data["vra_region"]["this"]["id"],
            default_item=False,
            supports_encryption=False,
            data_disk_caching="None",
            os_disk_caching="None",
            tags=[vra.storageprofile.AzureTagArgs(
                key="foo",
                value="bar",
            )])
        ```

        A storage profile azure resource supports the following arguments:

        :param str resource_name: The name of the resource.
        :param AzureArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(AzureArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 data_disk_caching: Optional[pulumi.Input[str]] = None,
                 default_item: Optional[pulumi.Input[bool]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 disk_type: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 os_disk_caching: Optional[pulumi.Input[str]] = None,
                 region_id: Optional[pulumi.Input[str]] = None,
                 storage_account_id: Optional[pulumi.Input[str]] = None,
                 supports_encryption: Optional[pulumi.Input[bool]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['AzureTagArgs']]]]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = AzureArgs.__new__(AzureArgs)

            __props__.__dict__["data_disk_caching"] = data_disk_caching
            if default_item is None and not opts.urn:
                raise TypeError("Missing required property 'default_item'")
            __props__.__dict__["default_item"] = default_item
            __props__.__dict__["description"] = description
            __props__.__dict__["disk_type"] = disk_type
            __props__.__dict__["name"] = name
            __props__.__dict__["os_disk_caching"] = os_disk_caching
            if region_id is None and not opts.urn:
                raise TypeError("Missing required property 'region_id'")
            __props__.__dict__["region_id"] = region_id
            __props__.__dict__["storage_account_id"] = storage_account_id
            __props__.__dict__["supports_encryption"] = supports_encryption
            __props__.__dict__["tags"] = tags
            __props__.__dict__["created_at"] = None
            __props__.__dict__["external_region_id"] = None
            __props__.__dict__["links"] = None
            __props__.__dict__["organization_id"] = None
            __props__.__dict__["owner"] = None
            __props__.__dict__["updated_at"] = None
        super(Azure, __self__).__init__(
            'vra:storageprofile/azure:Azure',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            created_at: Optional[pulumi.Input[str]] = None,
            data_disk_caching: Optional[pulumi.Input[str]] = None,
            default_item: Optional[pulumi.Input[bool]] = None,
            description: Optional[pulumi.Input[str]] = None,
            disk_type: Optional[pulumi.Input[str]] = None,
            external_region_id: Optional[pulumi.Input[str]] = None,
            links: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['AzureLinkArgs']]]]] = None,
            name: Optional[pulumi.Input[str]] = None,
            organization_id: Optional[pulumi.Input[str]] = None,
            os_disk_caching: Optional[pulumi.Input[str]] = None,
            owner: Optional[pulumi.Input[str]] = None,
            region_id: Optional[pulumi.Input[str]] = None,
            storage_account_id: Optional[pulumi.Input[str]] = None,
            supports_encryption: Optional[pulumi.Input[bool]] = None,
            tags: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['AzureTagArgs']]]]] = None,
            updated_at: Optional[pulumi.Input[str]] = None) -> 'Azure':
        """
        Get an existing Azure resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] created_at: Date when the entity was created. The date is in ISO 6801 and UTC.
        :param pulumi.Input[str] data_disk_caching: Indicates the caching mechanism for additional disk.
        :param pulumi.Input[bool] default_item: Indicates if this storage profile is a default profile.
        :param pulumi.Input[str] description: A human-friendly description.
        :param pulumi.Input[str] disk_type: Indicates the performance tier for the storage type. Premium disks are SSD backed and Standard disks are HDD backed.
        :param pulumi.Input[str] external_region_id: The id of the region as seen in the cloud provider for which this profile is defined.
        :param pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['AzureLinkArgs']]]] links: HATEOAS of the entity
        :param pulumi.Input[str] name: A human-friendly name used as an identifier in APIs that support this option.
        :param pulumi.Input[str] organization_id: The id of the organization this entity belongs to.
        :param pulumi.Input[str] os_disk_caching: Indicates the caching mechanism for OS disk. Default policy for OS disks is Read/Write.
        :param pulumi.Input[str] owner: Email of the user that owns the entity.
        :param pulumi.Input[str] region_id: A link to the region that is associated with the storage profile.
        :param pulumi.Input[str] storage_account_id: Id of a storage account where in the disk is placed.
        :param pulumi.Input[bool] supports_encryption: Indicates whether this storage policy should support encryption or not.
        :param pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['AzureTagArgs']]]] tags: A set of tag keys and optional values that were set on this Network Profile.
               example:[ { "key" : "ownedBy", "value": "Rainpole" } ]
        :param pulumi.Input[str] updated_at: Date when the entity was last updated. The date is ISO 8601 and UTC.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _AzureState.__new__(_AzureState)

        __props__.__dict__["created_at"] = created_at
        __props__.__dict__["data_disk_caching"] = data_disk_caching
        __props__.__dict__["default_item"] = default_item
        __props__.__dict__["description"] = description
        __props__.__dict__["disk_type"] = disk_type
        __props__.__dict__["external_region_id"] = external_region_id
        __props__.__dict__["links"] = links
        __props__.__dict__["name"] = name
        __props__.__dict__["organization_id"] = organization_id
        __props__.__dict__["os_disk_caching"] = os_disk_caching
        __props__.__dict__["owner"] = owner
        __props__.__dict__["region_id"] = region_id
        __props__.__dict__["storage_account_id"] = storage_account_id
        __props__.__dict__["supports_encryption"] = supports_encryption
        __props__.__dict__["tags"] = tags
        __props__.__dict__["updated_at"] = updated_at
        return Azure(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> pulumi.Output[str]:
        """
        Date when the entity was created. The date is in ISO 6801 and UTC.
        """
        return pulumi.get(self, "created_at")

    @property
    @pulumi.getter(name="dataDiskCaching")
    def data_disk_caching(self) -> pulumi.Output[str]:
        """
        Indicates the caching mechanism for additional disk.
        """
        return pulumi.get(self, "data_disk_caching")

    @property
    @pulumi.getter(name="defaultItem")
    def default_item(self) -> pulumi.Output[bool]:
        """
        Indicates if this storage profile is a default profile.
        """
        return pulumi.get(self, "default_item")

    @property
    @pulumi.getter
    def description(self) -> pulumi.Output[str]:
        """
        A human-friendly description.
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="diskType")
    def disk_type(self) -> pulumi.Output[str]:
        """
        Indicates the performance tier for the storage type. Premium disks are SSD backed and Standard disks are HDD backed.
        """
        return pulumi.get(self, "disk_type")

    @property
    @pulumi.getter(name="externalRegionId")
    def external_region_id(self) -> pulumi.Output[str]:
        """
        The id of the region as seen in the cloud provider for which this profile is defined.
        """
        return pulumi.get(self, "external_region_id")

    @property
    @pulumi.getter
    def links(self) -> pulumi.Output[Sequence['outputs.AzureLink']]:
        """
        HATEOAS of the entity
        """
        return pulumi.get(self, "links")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[str]:
        """
        A human-friendly name used as an identifier in APIs that support this option.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="organizationId")
    def organization_id(self) -> pulumi.Output[str]:
        """
        The id of the organization this entity belongs to.
        """
        return pulumi.get(self, "organization_id")

    @property
    @pulumi.getter(name="osDiskCaching")
    def os_disk_caching(self) -> pulumi.Output[str]:
        """
        Indicates the caching mechanism for OS disk. Default policy for OS disks is Read/Write.
        """
        return pulumi.get(self, "os_disk_caching")

    @property
    @pulumi.getter
    def owner(self) -> pulumi.Output[str]:
        """
        Email of the user that owns the entity.
        """
        return pulumi.get(self, "owner")

    @property
    @pulumi.getter(name="regionId")
    def region_id(self) -> pulumi.Output[str]:
        """
        A link to the region that is associated with the storage profile.
        """
        return pulumi.get(self, "region_id")

    @property
    @pulumi.getter(name="storageAccountId")
    def storage_account_id(self) -> pulumi.Output[str]:
        """
        Id of a storage account where in the disk is placed.
        """
        return pulumi.get(self, "storage_account_id")

    @property
    @pulumi.getter(name="supportsEncryption")
    def supports_encryption(self) -> pulumi.Output[bool]:
        """
        Indicates whether this storage policy should support encryption or not.
        """
        return pulumi.get(self, "supports_encryption")

    @property
    @pulumi.getter
    def tags(self) -> pulumi.Output[Sequence['outputs.AzureTag']]:
        """
        A set of tag keys and optional values that were set on this Network Profile.
        example:[ { "key" : "ownedBy", "value": "Rainpole" } ]
        """
        return pulumi.get(self, "tags")

    @property
    @pulumi.getter(name="updatedAt")
    def updated_at(self) -> pulumi.Output[str]:
        """
        Date when the entity was last updated. The date is ISO 8601 and UTC.
        """
        return pulumi.get(self, "updated_at")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from . import _utilities

__all__ = ['ProviderArgs', 'Provider']

@pulumi.input_type
class ProviderArgs:
    def __init__(__self__, *,
                 url: pulumi.Input[str],
                 access_token: Optional[pulumi.Input[str]] = None,
                 insecure: Optional[pulumi.Input[bool]] = None,
                 reauthorize_timeout: Optional[pulumi.Input[str]] = None,
                 refresh_token: Optional[pulumi.Input[str]] = None):
        """
        The set of arguments for constructing a Provider resource.
        :param pulumi.Input[str] url: The base url for API operations.
        :param pulumi.Input[str] access_token: The access token for API operations.
        :param pulumi.Input[bool] insecure: Specify whether to validate TLS certificates.
        :param pulumi.Input[str] reauthorize_timeout: Specify timeout for how often to reauthorize the access token
        :param pulumi.Input[str] refresh_token: The refresh token for API operations.
        """
        pulumi.set(__self__, "url", url)
        if access_token is not None:
            pulumi.set(__self__, "access_token", access_token)
        if insecure is not None:
            pulumi.set(__self__, "insecure", insecure)
        if reauthorize_timeout is not None:
            pulumi.set(__self__, "reauthorize_timeout", reauthorize_timeout)
        if refresh_token is not None:
            pulumi.set(__self__, "refresh_token", refresh_token)

    @property
    @pulumi.getter
    def url(self) -> pulumi.Input[str]:
        """
        The base url for API operations.
        """
        return pulumi.get(self, "url")

    @url.setter
    def url(self, value: pulumi.Input[str]):
        pulumi.set(self, "url", value)

    @property
    @pulumi.getter(name="accessToken")
    def access_token(self) -> Optional[pulumi.Input[str]]:
        """
        The access token for API operations.
        """
        return pulumi.get(self, "access_token")

    @access_token.setter
    def access_token(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "access_token", value)

    @property
    @pulumi.getter
    def insecure(self) -> Optional[pulumi.Input[bool]]:
        """
        Specify whether to validate TLS certificates.
        """
        return pulumi.get(self, "insecure")

    @insecure.setter
    def insecure(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "insecure", value)

    @property
    @pulumi.getter(name="reauthorizeTimeout")
    def reauthorize_timeout(self) -> Optional[pulumi.Input[str]]:
        """
        Specify timeout for how often to reauthorize the access token
        """
        return pulumi.get(self, "reauthorize_timeout")

    @reauthorize_timeout.setter
    def reauthorize_timeout(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "reauthorize_timeout", value)

    @property
    @pulumi.getter(name="refreshToken")
    def refresh_token(self) -> Optional[pulumi.Input[str]]:
        """
        The refresh token for API operations.
        """
        return pulumi.get(self, "refresh_token")

    @refresh_token.setter
    def refresh_token(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "refresh_token", value)


class Provider(pulumi.ProviderResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 access_token: Optional[pulumi.Input[str]] = None,
                 insecure: Optional[pulumi.Input[bool]] = None,
                 reauthorize_timeout: Optional[pulumi.Input[str]] = None,
                 refresh_token: Optional[pulumi.Input[str]] = None,
                 url: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        The provider type for the vra package. By default, resources use package-wide configuration
        settings, however an explicit `Provider` instance may be created and passed during resource
        construction to achieve fine-grained programmatic control over provider settings. See the
        [documentation](https://www.pulumi.com/docs/reference/programming-model/#providers) for more information.

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] access_token: The access token for API operations.
        :param pulumi.Input[bool] insecure: Specify whether to validate TLS certificates.
        :param pulumi.Input[str] reauthorize_timeout: Specify timeout for how often to reauthorize the access token
        :param pulumi.Input[str] refresh_token: The refresh token for API operations.
        :param pulumi.Input[str] url: The base url for API operations.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: ProviderArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        The provider type for the vra package. By default, resources use package-wide configuration
        settings, however an explicit `Provider` instance may be created and passed during resource
        construction to achieve fine-grained programmatic control over provider settings. See the
        [documentation](https://www.pulumi.com/docs/reference/programming-model/#providers) for more information.

        :param str resource_name: The name of the resource.
        :param ProviderArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(ProviderArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 access_token: Optional[pulumi.Input[str]] = None,
                 insecure: Optional[pulumi.Input[bool]] = None,
                 reauthorize_timeout: Optional[pulumi.Input[str]] = None,
                 refresh_token: Optional[pulumi.Input[str]] = None,
                 url: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = ProviderArgs.__new__(ProviderArgs)

            __props__.__dict__["access_token"] = access_token
            __props__.__dict__["insecure"] = pulumi.Output.from_input(insecure).apply(pulumi.runtime.to_json) if insecure is not None else None
            __props__.__dict__["reauthorize_timeout"] = reauthorize_timeout
            __props__.__dict__["refresh_token"] = refresh_token
            if url is None and not opts.urn:
                raise TypeError("Missing required property 'url'")
            __props__.__dict__["url"] = url
        super(Provider, __self__).__init__(
            'vra',
            resource_name,
            __props__,
            opts)

    @property
    @pulumi.getter(name="accessToken")
    def access_token(self) -> pulumi.Output[Optional[str]]:
        """
        The access token for API operations.
        """
        return pulumi.get(self, "access_token")

    @property
    @pulumi.getter(name="reauthorizeTimeout")
    def reauthorize_timeout(self) -> pulumi.Output[Optional[str]]:
        """
        Specify timeout for how often to reauthorize the access token
        """
        return pulumi.get(self, "reauthorize_timeout")

    @property
    @pulumi.getter(name="refreshToken")
    def refresh_token(self) -> pulumi.Output[Optional[str]]:
        """
        The refresh token for API operations.
        """
        return pulumi.get(self, "refresh_token")

    @property
    @pulumi.getter
    def url(self) -> pulumi.Output[str]:
        """
        The base url for API operations.
        """
        return pulumi.get(self, "url")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['ProfileArgs', 'Profile']

@pulumi.input_type
class ProfileArgs:
    def __init__(__self__, *,
                 region_id: pulumi.Input[str],
                 description: Optional[pulumi.Input[str]] = None,
                 flavor_mappings: Optional[pulumi.Input[Sequence[pulumi.Input['ProfileFlavorMappingArgs']]]] = None,
                 name: Optional[pulumi.Input[str]] = None):
        """
        The set of arguments for constructing a Profile resource.
        :param pulumi.Input[str] region_id: The id of the region for which this profile is defined as in vRealize Automation(vRA).
        :param pulumi.Input[str] description: A human-friendly description.
        :param pulumi.Input[Sequence[pulumi.Input['ProfileFlavorMappingArgs']]] flavor_mappings: Map between global fabric flavor keys and fabric flavor descriptions.
        :param pulumi.Input[str] name: A human-friendly name used as an identifier in APIs that support this option.
        """
        pulumi.set(__self__, "region_id", region_id)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if flavor_mappings is not None:
            pulumi.set(__self__, "flavor_mappings", flavor_mappings)
        if name is not None:
            pulumi.set(__self__, "name", name)

    @property
    @pulumi.getter(name="regionId")
    def region_id(self) -> pulumi.Input[str]:
        """
        The id of the region for which this profile is defined as in vRealize Automation(vRA).
        """
        return pulumi.get(self, "region_id")

    @region_id.setter
    def region_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "region_id", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[str]]:
        """
        A human-friendly description.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="flavorMappings")
    def flavor_mappings(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['ProfileFlavorMappingArgs']]]]:
        """
        Map between global fabric flavor keys and fabric flavor descriptions.
        """
        return pulumi.get(self, "flavor_mappings")

    @flavor_mappings.setter
    def flavor_mappings(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['ProfileFlavorMappingArgs']]]]):
        pulumi.set(self, "flavor_mappings", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        A human-friendly name used as an identifier in APIs that support this option.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)


@pulumi.input_type
class _ProfileState:
    def __init__(__self__, *,
                 cloud_account_id: Optional[pulumi.Input[str]] = None,
                 created_at: Optional[pulumi.Input[str]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 external_region_id: Optional[pulumi.Input[str]] = None,
                 flavor_mappings: Optional[pulumi.Input[Sequence[pulumi.Input['ProfileFlavorMappingArgs']]]] = None,
                 links: Optional[pulumi.Input[Sequence[pulumi.Input['ProfileLinkArgs']]]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 org_id: Optional[pulumi.Input[str]] = None,
                 owner: Optional[pulumi.Input[str]] = None,
                 region_id: Optional[pulumi.Input[str]] = None,
                 updated_at: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering Profile resources.
        :param pulumi.Input[str] cloud_account_id: The ID of the cloud account this entity belongs to.
        :param pulumi.Input[str] created_at: Date when  entity was created. Date and time format is ISO 8601 and UTC.
        :param pulumi.Input[str] description: A human-friendly description.
        :param pulumi.Input[str] external_region_id: The ID of the external region that is associated with the flavor profile.
        :param pulumi.Input[Sequence[pulumi.Input['ProfileFlavorMappingArgs']]] flavor_mappings: Map between global fabric flavor keys and fabric flavor descriptions.
        :param pulumi.Input[Sequence[pulumi.Input['ProfileLinkArgs']]] links: HATEOAS of entity.
        :param pulumi.Input[str] name: A human-friendly name used as an identifier in APIs that support this option.
        :param pulumi.Input[str] org_id: ID of organization that entity belongs to.
        :param pulumi.Input[str] owner: Email of entity owner.
        :param pulumi.Input[str] region_id: The id of the region for which this profile is defined as in vRealize Automation(vRA).
        :param pulumi.Input[str] updated_at: Date when the entity was last updated. Date and time format is ISO 8601 and UTC.
        """
        if cloud_account_id is not None:
            pulumi.set(__self__, "cloud_account_id", cloud_account_id)
        if created_at is not None:
            pulumi.set(__self__, "created_at", created_at)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if external_region_id is not None:
            pulumi.set(__self__, "external_region_id", external_region_id)
        if flavor_mappings is not None:
            pulumi.set(__self__, "flavor_mappings", flavor_mappings)
        if links is not None:
            pulumi.set(__self__, "links", links)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if org_id is not None:
            pulumi.set(__self__, "org_id", org_id)
        if owner is not None:
            pulumi.set(__self__, "owner", owner)
        if region_id is not None:
            pulumi.set(__self__, "region_id", region_id)
        if updated_at is not None:
            pulumi.set(__self__, "updated_at", updated_at)

    @property
    @pulumi.getter(name="cloudAccountId")
    def cloud_account_id(self) -> Optional[pulumi.Input[str]]:
        """
        The ID of the cloud account this entity belongs to.
        """
        return pulumi.get(self, "cloud_account_id")

    @cloud_account_id.setter
    def cloud_account_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "cloud_account_id", value)

    @property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> Optional[pulumi.Input[str]]:
        """
        Date when  entity was created. Date and time format is ISO 8601 and UTC.
        """
        return pulumi.get(self, "created_at")

    @created_at.setter
    def created_at(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "created_at", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[str]]:
        """
        A human-friendly description.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="externalRegionId")
    def external_region_id(self) -> Optional[pulumi.Input[str]]:
        """
        The ID of the external region that is associated with the flavor profile.
        """
        return pulumi.get(self, "external_region_id")

    @external_region_id.setter
    def external_region_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "external_region_id", value)

    @property
    @pulumi.getter(name="flavorMappings")
    def flavor_mappings(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['ProfileFlavorMappingArgs']]]]:
        """
        Map between global fabric flavor keys and fabric flavor descriptions.
        """
        return pulumi.get(self, "flavor_mappings")

    @flavor_mappings.setter
    def flavor_mappings(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['ProfileFlavorMappingArgs']]]]):
        pulumi.set(self, "flavor_mappings", value)

    @property
    @pulumi.getter
    def links(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['ProfileLinkArgs']]]]:
        """
        HATEOAS of entity.
        """
        return pulumi.get(self, "links")

    @links.setter
    def links(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['ProfileLinkArgs']]]]):
        pulumi.set(self, "links", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        A human-friendly name used as an identifier in APIs that support this option.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="orgId")
    def org_id(self) -> Optional[pulumi.Input[str]]:
        """
        ID of organization that entity belongs to.
        """
        return pulumi.get(self, "org_id")

    @org_id.setter
    def org_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "org_id", value)

    @property
    @pulumi.getter
    def owner(self) -> Optional[pulumi.Input[str]]:
        """
        Email of entity owner.
        """
        return pulumi.get(self, "owner")

    @owner.setter
    def owner(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "owner", value)

    @property
    @pulumi.getter(name="regionId")
    def region_id(self) -> Optional[pulumi.Input[str]]:
        """
        The id of the region for which this profile is defined as in vRealize Automation(vRA).
        """
        return pulumi.get(self, "region_id")

    @region_id.setter
    def region_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "region_id", value)

    @property
    @pulumi.getter(name="updatedAt")
    def updated_at(self) -> Optional[pulumi.Input[str]]:
        """
        Date when the entity was last updated. Date and time format is ISO 8601 and UTC.
        """
        return pulumi.get(self, "updated_at")

    @updated_at.setter
    def updated_at(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "updated_at", value)


class Profile(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 flavor_mappings: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['ProfileFlavorMappingArgs']]]]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 region_id: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        ## Example Usage
        ### S
        This is an example of how to create a flavor profile resource.

        **Flavor profile:**

        ```python
        import pulumi
        import pulumiverse_vra as vra

        my_flavor_profile = vra.flavor.Profile("my-flavor-profile",
            description="my flavor",
            flavor_mappings=[
                vra.flavor.ProfileFlavorMappingArgs(
                    instance_type="t2.small",
                    name="small",
                ),
                vra.flavor.ProfileFlavorMappingArgs(
                    instance_type="t2.medium",
                    name="medium",
                ),
            ],
            region_id=data["vra_region"]["us-east-1-region"]["id"])
        ```

        An flavor profile resource supports the following arguments:

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] description: A human-friendly description.
        :param pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['ProfileFlavorMappingArgs']]]] flavor_mappings: Map between global fabric flavor keys and fabric flavor descriptions.
        :param pulumi.Input[str] name: A human-friendly name used as an identifier in APIs that support this option.
        :param pulumi.Input[str] region_id: The id of the region for which this profile is defined as in vRealize Automation(vRA).
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: ProfileArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        ## Example Usage
        ### S
        This is an example of how to create a flavor profile resource.

        **Flavor profile:**

        ```python
        import pulumi
        import pulumiverse_vra as vra

        my_flavor_profile = vra.flavor.Profile("my-flavor-profile",
            description="my flavor",
            flavor_mappings=[
                vra.flavor.ProfileFlavorMappingArgs(
                    instance_type="t2.small",
                    name="small",
                ),
                vra.flavor.ProfileFlavorMappingArgs(
                    instance_type="t2.medium",
                    name="medium",
                ),
            ],
            region_id=data["vra_region"]["us-east-1-region"]["id"])
        ```

        An flavor profile resource supports the following arguments:

        :param str resource_name: The name of the resource.
        :param ProfileArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(ProfileArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 flavor_mappings: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['ProfileFlavorMappingArgs']]]]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 region_id: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = ProfileArgs.__new__(ProfileArgs)

            __props__.__dict__["description"] = description
            __props__.__dict__["flavor_mappings"] = flavor_mappings
            __props__.__dict__["name"] = name
            if region_id is None and not opts.urn:
                raise TypeError("Missing required property 'region_id'")
            __props__.__dict__["region_id"] = region_id
            __props__.__dict__["cloud_account_id"] = None
            __props__.__dict__["created_at"] = None
            __props__.__dict__["external_region_id"] = None
            __props__.__dict__["links"] = None
            __props__.__dict__["org_id"] = None
            __props__.__dict__["owner"] = None
            __props__.__dict__["updated_at"] = None
        super(Profile, __self__).__init__(
            'vra:flavor/profile:Profile',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            cloud_account_id: Optional[pulumi.Input[str]] = None,
            created_at: Optional[pulumi.Input[str]] = None,
            description: Optional[pulumi.Input[str]] = None,
            external_region_id: Optional[pulumi.Input[str]] = None,
            flavor_mappings: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['ProfileFlavorMappingArgs']]]]] = None,
            links: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['ProfileLinkArgs']]]]] = None,
            name: Optional[pulumi.Input[str]] = None,
            org_id: Optional[pulumi.Input[str]] = None,
            owner: Optional[pulumi.Input[str]] = None,
            region_id: Optional[pulumi.Input[str]] = None,
            updated_at: Optional[pulumi.Input[str]] = None) -> 'Profile':
        """
        Get an existing Profile resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] cloud_account_id: The ID of the cloud account this entity belongs to.
        :param pulumi.Input[str] created_at: Date when  entity was created. Date and time format is ISO 8601 and UTC.
        :param pulumi.Input[str] description: A human-friendly description.
        :param pulumi.Input[str] external_region_id: The ID of the external region that is associated with the flavor profile.
        :param pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['ProfileFlavorMappingArgs']]]] flavor_mappings: Map between global fabric flavor keys and fabric flavor descriptions.
        :param pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['ProfileLinkArgs']]]] links: HATEOAS of entity.
        :param pulumi.Input[str] name: A human-friendly name used as an identifier in APIs that support this option.
        :param pulumi.Input[str] org_id: ID of organization that entity belongs to.
        :param pulumi.Input[str] owner: Email of entity owner.
        :param pulumi.Input[str] region_id: The id of the region for which this profile is defined as in vRealize Automation(vRA).
        :param pulumi.Input[str] updated_at: Date when the entity was last updated. Date and time format is ISO 8601 and UTC.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _ProfileState.__new__(_ProfileState)

        __props__.__dict__["cloud_account_id"] = cloud_account_id
        __props__.__dict__["created_at"] = created_at
        __props__.__dict__["description"] = description
        __props__.__dict__["external_region_id"] = external_region_id
        __props__.__dict__["flavor_mappings"] = flavor_mappings
        __props__.__dict__["links"] = links
        __props__.__dict__["name"] = name
        __props__.__dict__["org_id"] = org_id
        __props__.__dict__["owner"] = owner
        __props__.__dict__["region_id"] = region_id
        __props__.__dict__["updated_at"] = updated_at
        return Profile(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="cloudAccountId")
    def cloud_account_id(self) -> pulumi.Output[str]:
        """
        The ID of the cloud account this entity belongs to.
        """
        return pulumi.get(self, "cloud_account_id")

    @property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> pulumi.Output[str]:
        """
        Date when  entity was created. Date and time format is ISO 8601 and UTC.
        """
        return pulumi.get(self, "created_at")

    @property
    @pulumi.getter
    def description(self) -> pulumi.Output[Optional[str]]:
        """
        A human-friendly description.
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="externalRegionId")
    def external_region_id(self) -> pulumi.Output[str]:
        """
        The ID of the external region that is associated with the flavor profile.
        """
        return pulumi.get(self, "external_region_id")

    @property
    @pulumi.getter(name="flavorMappings")
    def flavor_mappings(self) -> pulumi.Output[Optional[Sequence['outputs.ProfileFlavorMapping']]]:
        """
        Map between global fabric flavor keys and fabric flavor descriptions.
        """
        return pulumi.get(self, "flavor_mappings")

    @property
    @pulumi.getter
    def links(self) -> pulumi.Output[Sequence['outputs.ProfileLink']]:
        """
        HATEOAS of entity.
        """
        return pulumi.get(self, "links")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[str]:
        """
        A human-friendly name used as an identifier in APIs that support this option.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="orgId")
    def org_id(self) -> pulumi.Output[str]:
        """
        ID of organization that entity belongs to.
        """
        return pulumi.get(self, "org_id")

    @property
    @pulumi.getter
    def owner(self) -> pulumi.Output[str]:
        """
        Email of entity owner.
        """
        return pulumi.get(self, "owner")

    @property
    @pulumi.getter(name="regionId")
    def region_id(self) -> pulumi.Output[str]:
        """
        The id of the region for which this profile is defined as in vRealize Automation(vRA).
        """
        return pulumi.get(self, "region_id")

    @property
    @pulumi.getter(name="updatedAt")
    def updated_at(self) -> pulumi.Output[str]:
        """
        Date when the entity was last updated. Date and time format is ISO 8601 and UTC.
        """
        return pulumi.get(self, "updated_at")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities

__all__ = [
    'ComputeLink',
    'ComputeTag',
    'DatastoreVSphereLink',
    'DatastoreVSphereTag',
    'NetworkVSphereLink',
    'NetworkVSphereTag',
    'GetComputeLinkResult',
    'GetComputeTagResult',
    'GetDatastoreVSphereLinkResult',
    'GetDatastoreVSphereTagResult',
    'GetNetworkLinkResult',
    'GetNetworkTagResult',
    'GetStorageAccountAzureLinkResult',
    'GetStoragePolicyVSphereLinkResult',
]

@pulumi.output_type
class ComputeLink(dict):
    def __init__(__self__, *,
                 rel: str,
                 href: Optional[str] = None,
                 hrefs: Optional[Sequence[str]] = None):
        pulumi.set(__self__, "rel", rel)
        if href is not None:
            pulumi.set(__self__, "href", href)
        if hrefs is not None:
            pulumi.set(__self__, "hrefs", hrefs)

    @property
    @pulumi.getter
    def rel(self) -> str:
        return pulumi.get(self, "rel")

    @property
    @pulumi.getter
    def href(self) -> Optional[str]:
        return pulumi.get(self, "href")

    @property
    @pulumi.getter
    def hrefs(self) -> Optional[Sequence[str]]:
        return pulumi.get(self, "hrefs")


@pulumi.output_type
class ComputeTag(dict):
    def __init__(__self__, *,
                 key: str,
                 value: str):
        """
        :param str key: Tag’s key.
        :param str value: Tag’s value.
        """
        pulumi.set(__self__, "key", key)
        pulumi.set(__self__, "value", value)

    @property
    @pulumi.getter
    def key(self) -> str:
        """
        Tag’s key.
        """
        return pulumi.get(self, "key")

    @property
    @pulumi.getter
    def value(self) -> str:
        """
        Tag’s value.
        """
        return pulumi.get(self, "value")


@pulumi.output_type
class DatastoreVSphereLink(dict):
    def __init__(__self__, *,
                 rel: str,
                 href: Optional[str] = None,
                 hrefs: Optional[Sequence[str]] = None):
        pulumi.set(__self__, "rel", rel)
        if href is not None:
            pulumi.set(__self__, "href", href)
        if hrefs is not None:
            pulumi.set(__self__, "hrefs", hrefs)

    @property
    @pulumi.getter
    def rel(self) -> str:
        return pulumi.get(self, "rel")

    @property
    @pulumi.getter
    def href(self) -> Optional[str]:
        return pulumi.get(self, "href")

    @property
    @pulumi.getter
    def hrefs(self) -> Optional[Sequence[str]]:
        return pulumi.get(self, "hrefs")


@pulumi.output_type
class DatastoreVSphereTag(dict):
    def __init__(__self__, *,
                 key: str,
                 value: str):
        """
        :param str key: Tag’s key.
        :param str value: Tag’s value.
        """
        pulumi.set(__self__, "key", key)
        pulumi.set(__self__, "value", value)

    @property
    @pulumi.getter
    def key(self) -> str:
        """
        Tag’s key.
        """
        return pulumi.get(self, "key")

    @property
    @pulumi.getter
    def value(self) -> str:
        """
        Tag’s value.
        """
        return pulumi.get(self, "value")


@pulumi.output_type
class NetworkVSphereLink(dict):
    def __init__(__self__, *,
                 rel: str,
                 href: Optional[str] = None,
                 hrefs: Optional[Sequence[str]] = None):
        pulumi.set(__self__, "rel", rel)
        if href is not None:
            pulumi.set(__self__, "href", href)
        if hrefs is not None:
            pulumi.set(__self__, "hrefs", hrefs)

    @property
    @pulumi.getter
    def rel(self) -> str:
        return pulumi.get(self, "rel")

    @property
    @pulumi.getter
    def href(self) -> Optional[str]:
        return pulumi.get(self, "href")

    @property
    @pulumi.getter
    def hrefs(self) -> Optional[Sequence[str]]:
        return pulumi.get(self, "hrefs")


@pulumi.output_type
class NetworkVSphereTag(dict):
    def __init__(__self__, *,
                 key: str,
                 value: str):
        pulumi.set(__self__, "key", key)
        pulumi.set(__self__, "value", value)

    @property
    @pulumi.getter
    def key(self) -> str:
        return pulumi.get(self, "key")

    @property
    @pulumi.getter
    def value(self) -> str:
        return pulumi.get(self, "value")


@pulumi.output_type
class GetComputeLinkResult(dict):
    def __init__(__self__, *,
                 rel: str,
                 href: Optional[str] = None,
                 hrefs: Optional[Sequence[str]] = None):
        pulumi.set(__self__, "rel", rel)
        if href is not None:
            pulumi.set(__self__, "href", href)
        if hrefs is not None:
            pulumi.set(__self__, "hrefs", hrefs)

    @property
    @pulumi.getter
    def rel(self) -> str:
        return pulumi.get(self, "rel")

    @property
    @pulumi.getter
    def href(self) -> Optional[str]:
        return pulumi.get(self, "href")

    @property
    @pulumi.getter
    def hrefs(self) -> Optional[Sequence[str]]:
        return pulumi.get(self, "hrefs")


@pulumi.output_type
class GetComputeTagResult(dict):
    def __init__(__self__, *,
                 key: str,
                 value: str):
        """
        :param str key: Tag’s key.
        :param str value: Tag’s value.
        """
        pulumi.set(__self__, "key", key)
        pulumi.set(__self__, "value", value)

    @property
    @pulumi.getter
    def key(self) -> str:
        """
        Tag’s key.
        """
        return pulumi.get(self, "key")

    @property
    @pulumi.getter
    def value(self) -> str:
        """
        Tag’s value.
        """
        return pulumi.get(self, "value")


@pulumi.output_type
class GetDatastoreVSphereLinkResult(dict):
    def __init__(__self__, *,
                 rel: str,
                 href: Optional[str] = None,
                 hrefs: Optional[Sequence[str]] = None):
        pulumi.set(__self__, "rel", rel)
        if href is not None:
            pulumi.set(__self__, "href", href)
        if hrefs is not None:
            pulumi.set(__self__, "hrefs", hrefs)

    @property
    @pulumi.getter
    def rel(self) -> str:
        return pulumi.get(self, "rel")

    @property
    @pulumi.getter
    def href(self) -> Optional[str]:
        return pulumi.get(self, "href")

    @property
    @pulumi.getter
    def hrefs(self) -> Optional[Sequence[str]]:
        return pulumi.get(self, "hrefs")


@pulumi.output_type
class GetDatastoreVSphereTagResult(dict):
    def __init__(__self__, *,
                 key: str,
                 value: str):
        """
        :param str key: Tag’s key.
        :param str value: Tag’s value.
        """
        pulumi.set(__self__, "key", key)
        pulumi.set(__self__, "value", value)

    @property
    @pulumi.getter
    def key(self) -> str:
        """
        Tag’s key.
        """
        return pulumi.get(self, "key")

    @property
    @pulumi.getter
    def value(self) -> str:
        """
        Tag’s value.
        """
        return pulumi.get(self, "value")


@pulumi.output_type
class GetNetworkLinkResult(dict):
    def __init__(__self__, *,
                 rel: str,
                 href: Optional[str] = None,
                 hrefs: Optional[Sequence[str]] = None):
        pulumi.set(__self__, "rel", rel)
        if href is not None:
            pulumi.set(__self__, "href", href)
        if hrefs is not None:
            pulumi.set(__self__, "hrefs", hrefs)

    @property
    @pulumi.getter
    def rel(self) -> str:
        return pulumi.get(self, "rel")

    @property
    @pulumi.getter
    def href(self) -> Optional[str]:
        return pulumi.get(self, "href")

    @property
    @pulumi.getter
    def hrefs(self) -> Optional[Sequence[str]]:
        return pulumi.get(self, "hrefs")


@pulumi.output_type
class GetNetworkTagResult(dict):
    def __init__(__self__, *,
                 key: str,
                 value: str):
        pulumi.set(__self__, "key", key)
        pulumi.set(__self__, "value", value)

    @property
    @pulumi.getter
    def key(self) -> str:
        return pulumi.get(self, "key")

    @property
    @pulumi.getter
    def value(self) -> str:
        return pulumi.get(self, "value")


@pulumi.output_type
class GetStorageAccountAzureLinkResult(dict):
    def __init__(__self__, *,
                 rel: str,
                 href: Optional[str] = None,
                 hrefs: Optional[Sequence[str]] = None):
        pulumi.set(__self__, "rel", rel)
        if href is not None:
            pulumi.set(__self__, "href", href)
        if hrefs is not None:
            pulumi.set(__self__, "hrefs", hrefs)

    @property
    @pulumi.getter
    def rel(self) -> str:
        return pulumi.get(self, "rel")

    @property
    @pulumi.getter
    def href(self) -> Optional[str]:
        return pulumi.get(self, "href")

    @property
    @pulumi.getter
    def hrefs(self) -> Optional[Sequence[str]]:
        return pulumi.get(self, "hrefs")


@pulumi.output_type
class GetStoragePolicyVSphereLinkResult(dict):
    def __init__(__self__, *,
                 rel: str,
                 href: Optional[str] = None,
                 hrefs: Optional[Sequence[str]] = None):
        pulumi.set(__self__, "rel", rel)
        if href is not None:
            pulumi.set(__self__, "href", href)
        if hrefs is not None:
            pulumi.set(__self__, "hrefs", hrefs)

    @property
    @pulumi.getter
    def rel(self) -> str:
        return pulumi.get(self, "rel")

    @property
    @pulumi.getter
    def href(self) -> Optional[str]:
        return pulumi.get(self, "href")

    @property
    @pulumi.getter
    def hrefs(self) -> Optional[Sequence[str]]:
        return pulumi.get(self, "hrefs")





# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = [
    'GetMachineResult',
    'AwaitableGetMachineResult',
    'get_machine',
    'get_machine_output',
]

@pulumi.output_type
class GetMachineResult:
    """
    A collection of values returned by getMachine.
    """
    def __init__(__self__, address=None, cloud_account_ids=None, created_at=None, custom_properties=None, deployment_id=None, description=None, external_id=None, external_region_id=None, external_zone_id=None, filter=None, id=None, links=None, name=None, org_id=None, owner=None, power_state=None, project_id=None, tags=None, updated_at=None):
        if address and not isinstance(address, str):
            raise TypeError("Expected argument 'address' to be a str")
        pulumi.set(__self__, "address", address)
        if cloud_account_ids and not isinstance(cloud_account_ids, list):
            raise TypeError("Expected argument 'cloud_account_ids' to be a list")
        pulumi.set(__self__, "cloud_account_ids", cloud_account_ids)
        if created_at and not isinstance(created_at, str):
            raise TypeError("Expected argument 'created_at' to be a str")
        pulumi.set(__self__, "created_at", created_at)
        if custom_properties and not isinstance(custom_properties, dict):
            raise TypeError("Expected argument 'custom_properties' to be a dict")
        pulumi.set(__self__, "custom_properties", custom_properties)
        if deployment_id and not isinstance(deployment_id, str):
            raise TypeError("Expected argument 'deployment_id' to be a str")
        pulumi.set(__self__, "deployment_id", deployment_id)
        if description and not isinstance(description, str):
            raise TypeError("Expected argument 'description' to be a str")
        pulumi.set(__self__, "description", description)
        if external_id and not isinstance(external_id, str):
            raise TypeError("Expected argument 'external_id' to be a str")
        pulumi.set(__self__, "external_id", external_id)
        if external_region_id and not isinstance(external_region_id, str):
            raise TypeError("Expected argument 'external_region_id' to be a str")
        pulumi.set(__self__, "external_region_id", external_region_id)
        if external_zone_id and not isinstance(external_zone_id, str):
            raise TypeError("Expected argument 'external_zone_id' to be a str")
        pulumi.set(__self__, "external_zone_id", external_zone_id)
        if filter and not isinstance(filter, str):
            raise TypeError("Expected argument 'filter' to be a str")
        pulumi.set(__self__, "filter", filter)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if links and not isinstance(links, list):
            raise TypeError("Expected argument 'links' to be a list")
        pulumi.set(__self__, "links", links)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if org_id and not isinstance(org_id, str):
            raise TypeError("Expected argument 'org_id' to be a str")
        pulumi.set(__self__, "org_id", org_id)
        if owner and not isinstance(owner, str):
            raise TypeError("Expected argument 'owner' to be a str")
        pulumi.set(__self__, "owner", owner)
        if power_state and not isinstance(power_state, str):
            raise TypeError("Expected argument 'power_state' to be a str")
        pulumi.set(__self__, "power_state", power_state)
        if project_id and not isinstance(project_id, str):
            raise TypeError("Expected argument 'project_id' to be a str")
        pulumi.set(__self__, "project_id", project_id)
        if tags and not isinstance(tags, list):
            raise TypeError("Expected argument 'tags' to be a list")
        pulumi.set(__self__, "tags", tags)
        if updated_at and not isinstance(updated_at, str):
            raise TypeError("Expected argument 'updated_at' to be a str")
        pulumi.set(__self__, "updated_at", updated_at)

    @property
    @pulumi.getter
    def address(self) -> str:
        """
        Primary address allocated or in use by this machine. The actual type of the address depends on the adapter type. Typically it is either the public or the external IP address.
        """
        return pulumi.get(self, "address")

    @property
    @pulumi.getter(name="cloudAccountIds")
    def cloud_account_ids(self) -> Sequence[str]:
        """
        Set of ids of the cloud accounts this resource belongs to.
        """
        return pulumi.get(self, "cloud_account_ids")

    @property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> str:
        """
        Date when the entity was created. The date is in ISO 6801 and UTC.
        """
        return pulumi.get(self, "created_at")

    @property
    @pulumi.getter(name="customProperties")
    def custom_properties(self) -> Mapping[str, Any]:
        """
        Additional properties that may be used to extend the base resource.
        """
        return pulumi.get(self, "custom_properties")

    @property
    @pulumi.getter(name="deploymentId")
    def deployment_id(self) -> str:
        """
        Deployment id that is associated with this resource.
        """
        return pulumi.get(self, "deployment_id")

    @property
    @pulumi.getter
    def description(self) -> Optional[str]:
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="externalId")
    def external_id(self) -> str:
        """
        External entity Id on the provider side.
        """
        return pulumi.get(self, "external_id")

    @property
    @pulumi.getter(name="externalRegionId")
    def external_region_id(self) -> str:
        """
        The external regionId of the resource.
        """
        return pulumi.get(self, "external_region_id")

    @property
    @pulumi.getter(name="externalZoneId")
    def external_zone_id(self) -> str:
        """
        The external zoneId of the resource.
        """
        return pulumi.get(self, "external_zone_id")

    @property
    @pulumi.getter
    def filter(self) -> Optional[str]:
        return pulumi.get(self, "filter")

    @property
    @pulumi.getter
    def id(self) -> str:
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def links(self) -> Sequence['outputs.GetMachineLinkResult']:
        """
        HATEOAS of the entity
        """
        return pulumi.get(self, "links")

    @property
    @pulumi.getter
    def name(self) -> str:
        """
        A human-friendly name used as an identifier in APIs that support this option.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="orgId")
    def org_id(self) -> str:
        """
        The id of the organization this entity belongs to.
        """
        return pulumi.get(self, "org_id")

    @property
    @pulumi.getter
    def owner(self) -> str:
        """
        Email of the user that owns the entity.
        """
        return pulumi.get(self, "owner")

    @property
    @pulumi.getter(name="powerState")
    def power_state(self) -> str:
        """
        Power state of machine.
        """
        return pulumi.get(self, "power_state")

    @property
    @pulumi.getter(name="projectId")
    def project_id(self) -> str:
        """
        The id of the project this resource belongs to.
        """
        return pulumi.get(self, "project_id")

    @property
    @pulumi.getter
    def tags(self) -> Sequence['outputs.GetMachineTagResult']:
        """
        A set of tag keys and optional values that were set on this resource.
        example:[ { "key" : "ownedBy", "value": "Rainpole" } ]
        """
        return pulumi.get(self, "tags")

    @property
    @pulumi.getter(name="updatedAt")
    def updated_at(self) -> str:
        return pulumi.get(self, "updated_at")


class AwaitableGetMachineResult(GetMachineResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetMachineResult(
            address=self.address,
            cloud_account_ids=self.cloud_account_ids,
            created_at=self.created_at,
            custom_properties=self.custom_properties,
            deployment_id=self.deployment_id,
            description=self.description,
            external_id=self.external_id,
            external_region_id=self.external_region_id,
            external_zone_id=self.external_zone_id,
            filter=self.filter,
            id=self.id,
            links=self.links,
            name=self.name,
            org_id=self.org_id,
            owner=self.owner,
            power_state=self.power_state,
            project_id=self.project_id,
            tags=self.tags,
            updated_at=self.updated_at)


def get_machine(description: Optional[str] = None,
                filter: Optional[str] = None,
                id: Optional[str] = None,
                tags: Optional[Sequence[pulumi.InputType['GetMachineTagArgs']]] = None,
                opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetMachineResult:
    """
    ## ---layout: "vra"

    page_title: "VMware vRealize Automation: machine.Machine"
    description: |-
      Provides a data lookup for vra_machine.
    ---

    # Data Source: machine.Machine
    ## Example Usage
    ### S

    This is an example of how to read a machine data source.

    ```python
    import pulumi
    import pulumi_vra as vra

    this = vra.machine.get_machine(id=var["my_machine_id"])
    ```

    **Machine data source filter by name:**
    ```python
    import pulumi
    import pulumi_vra as vra

    this = vra.machine.get_machine(filter=f"name eq '{var['machine_name']}'")
    ```


    :param str description: A human-friendly description.
    :param str filter: Filter query string that is supported by vRA multi-cloud IaaS API. Example: regionId eq '<regionId>' and cloudAccountId eq '<cloudAccountId>'.
    :param str id: The id of the image profile instance.
    :param Sequence[pulumi.InputType['GetMachineTagArgs']] tags: A set of tag keys and optional values that were set on this resource.
           example:[ { "key" : "ownedBy", "value": "Rainpole" } ]
    """
    __args__ = dict()
    __args__['description'] = description
    __args__['filter'] = filter
    __args__['id'] = id
    __args__['tags'] = tags
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('vra:machine/getMachine:getMachine', __args__, opts=opts, typ=GetMachineResult).value

    return AwaitableGetMachineResult(
        address=__ret__.address,
        cloud_account_ids=__ret__.cloud_account_ids,
        created_at=__ret__.created_at,
        custom_properties=__ret__.custom_properties,
        deployment_id=__ret__.deployment_id,
        description=__ret__.description,
        external_id=__ret__.external_id,
        external_region_id=__ret__.external_region_id,
        external_zone_id=__ret__.external_zone_id,
        filter=__ret__.filter,
        id=__ret__.id,
        links=__ret__.links,
        name=__ret__.name,
        org_id=__ret__.org_id,
        owner=__ret__.owner,
        power_state=__ret__.power_state,
        project_id=__ret__.project_id,
        tags=__ret__.tags,
        updated_at=__ret__.updated_at)


@_utilities.lift_output_func(get_machine)
def get_machine_output(description: Optional[pulumi.Input[Optional[str]]] = None,
                       filter: Optional[pulumi.Input[Optional[str]]] = None,
                       id: Optional[pulumi.Input[Optional[str]]] = None,
                       tags: Optional[pulumi.Input[Optional[Sequence[pulumi.InputType['GetMachineTagArgs']]]]] = None,
                       opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetMachineResult]:
    """
    ## ---layout: "vra"

    page_title: "VMware vRealize Automation: machine.Machine"
    description: |-
      Provides a data lookup for vra_machine.
    ---

    # Data Source: machine.Machine
    ## Example Usage
    ### S

    This is an example of how to read a machine data source.

    ```python
    import pulumi
    import pulumi_vra as vra

    this = vra.machine.get_machine(id=var["my_machine_id"])
    ```

    **Machine data source filter by name:**
    ```python
    import pulumi
    import pulumi_vra as vra

    this = vra.machine.get_machine(filter=f"name eq '{var['machine_name']}'")
    ```


    :param str description: A human-friendly description.
    :param str filter: Filter query string that is supported by vRA multi-cloud IaaS API. Example: regionId eq '<regionId>' and cloudAccountId eq '<cloudAccountId>'.
    :param str id: The id of the image profile instance.
    :param Sequence[pulumi.InputType['GetMachineTagArgs']] tags: A set of tag keys and optional values that were set on this resource.
           example:[ { "key" : "ownedBy", "value": "Rainpole" } ]
    """
    ...
